@@ -24,11 +24,15 @@ from molSimplify.Informatics.MOF.PBC_functions import *
 # This MOF RAC generator assumes that pymatgen is installed.                            #
 # Pymatgen is used to get the primitive cell.                                           #
 #########################################################################################
-# from pymatgen.io.cif import CifParser
-# def get_primitive(datapath, writepath):
-#     s = CifParser(datapath, occupancy_tolerance=1).get_structures()[0]
-#     sprim = s.get_primitive_structure()
-#     sprim.to("cif",writepath)
+from pymatgen.io.cif import CifParser
+
+
+def get_primitive(datapath, writepath):
+    s = CifParser(datapath, occupancy_tolerance=1).get_structures()[0]
+    sprim = s.get_primitive_structure()
+    sprim.to("cif", writepath)
+
+
 '''<<<< END OF CODE TO COMPUTE PRIMITIVE UNIT CELLS >>>>'''
 
 #########################################################################################
@@ -111,8 +115,8 @@ def make_MOF_SBU_RACs(SBUlist, SBU_subgraph, molcif, depth, name,cell,anchoring_
                     descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,results_dictionary['colnames'],results_dictionary['results'],'D_func','all')
                     # print('4',len(descriptor_names),len(descriptors))
                 else:
-                    descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,results_dictionary['colnames'],list(numpy.zeros(int(6*(depth + 1)))),'func','all')
-                    descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,results_dictionary['colnames'],list(numpy.zeros(int(6*(depth + 1)))),'D_func','all')
+                    descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,results_dictionary['colnames'],list([numpy.zeros(int(6*(depth + 1)))]),'func','all')
+                    descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,results_dictionary['colnames'],list([numpy.zeros(int(6*(depth + 1)))]),'D_func','all')
                     # print('5b',len(descriptor_names),len(descriptors))
                 for val in descriptors:
                     if not (type(val) == float or isinstance(val, numpy.float64)):
@@ -268,7 +272,7 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
         tmpstr = "Failed to featurize %s: large primitive cell\n"%(name)
         write2file(path,"/FailedStructures.log",tmpstr)
         return full_names, full_descriptors
-    distance_mat = compute_distance_matrix2(cell_v,cart_coords)
+    distance_mat = compute_distance_matrix3(cell_v,cart_coords)
     try:
         adj_matrix=compute_adj_matrix(distance_mat,allatomtypes)
     except NotImplementedError:
@@ -289,7 +293,9 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     """""""""
 
     n_components, labels_components = sparse.csgraph.connected_components(csgraph=adj_matrix, directed=False, return_labels=True)
-    metal_list = set([at for at in molcif.findMetal()])
+    metal_list = set([at for at in molcif.findMetal(transition_metals_only=False)])
+    # print('##### METAL LIST', metal_list, [molcif.getAtom(val).symbol() for val in list(metal_list)])
+    # print('##### METAL LIST', metal_list, [val.symbol() for val in molcif.atoms])
     if not len(metal_list) > 0:
         full_names = [0]
         full_descriptors = [0]
@@ -299,7 +305,7 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
 
     for comp in range(n_components):
         inds_in_comp = [i for i in range(len(labels_components)) if labels_components[i]==comp]
-        if not set(inds_in_comp)&metal_list:
+        if not set(inds_in_comp) & metal_list:
             full_names = [0]
             full_descriptors = [0]
             tmpstr = "Failed to featurize %s: solvent molecules\n"%(name)
@@ -319,11 +325,13 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     Logs the atom types of the connecting atoms to the metal in logpath.
     """""""""
     SBUlist = set() 
-    metal_list = set([at for at in molcif.findMetal()])
-    [SBUlist.update(set([metal])) for metal in molcif.findMetal()] #Remove all metals as part of the SBU
-    [SBUlist.update(set(molcif.getBondedAtomsSmart(metal))) for metal in molcif.findMetal()]
+    metal_list = set([at for at in molcif.findMetal(transition_metals_only=False)])
+    # print('##### METAL LIST2', metal_list, [molcif.getAtom(val).symbol() for val in list(metal_list)])
+    # print('##### all LIST2', metal_list, [val.symbol() for val in molcif.atoms])
+    [SBUlist.update(set([metal])) for metal in molcif.findMetal(transition_metals_only=False)] #Remove all metals as part of the SBU
+    [SBUlist.update(set(molcif.getBondedAtomsSmart(metal))) for metal in molcif.findMetal(transition_metals_only=False)]
     removelist = set()
-    [removelist.update(set([metal])) for metal in molcif.findMetal()] #Remove all metals as part of the SBU
+    [removelist.update(set([metal])) for metal in molcif.findMetal(transition_metals_only=False)] #Remove all metals as part of the SBU
     for metal in removelist:
         bonded_atoms = set(molcif.getBondedAtomsSmart(metal))
         bonded_atoms_types = set([str(allatomtypes[at]) for at in set(molcif.getBondedAtomsSmart(metal))])
@@ -362,7 +370,7 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     anc_atoms = set()
     for linker in linker_list:
         for atom_linker in linker:
-            bonded2atom  = np.nonzero(adj_matrix[atom_linker,:])[1] 
+            bonded2atom = np.nonzero(adj_matrix[atom_linker,:])[1] 
             if set(bonded2atom) & metal_list:
                 anc_atoms.add(atom_linker)
     """""""""
@@ -408,15 +416,15 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
             else: 
                 # check number of times we cross PBC :
                 # TODO: we still can fail in multidentate ligands!
-                linker_cart_coords=np.array([at.coords() \
-                        for at in [molcif.getAtom(val) for val in atoms_list]])
+                linker_cart_coords = np.array([
+                    at.coords() for at in [molcif.getAtom(val) for val in atoms_list]])
                 linker_adjmat = np.array(linker_subgraphlist[ii].todense())
                 pr_image_organic = ligand_detect(cell_v,linker_cart_coords,linker_adjmat,linkeranchors_list)
                 sbu_temp = linkeranchors_atoms.copy()
                 sbu_temp.update({val for val in initial_SBU_list[list(sbu_connect_list)[0]]})
                 sbu_temp = list(sbu_temp)
-                sbu_cart_coords=np.array([at.coords() \
-                       for at in [molcif.getAtom(val) for val in sbu_temp]])
+                sbu_cart_coords = np.array([
+                    at.coords() for at in [molcif.getAtom(val) for val in sbu_temp]])
                 sbu_adjmat = slice_mat(adj_matrix.todense(),sbu_temp) 
                 pr_image_sbu = ligand_detect(cell_v,sbu_cart_coords,sbu_adjmat,set(range(len(linkeranchors_list))))
                 if not (len(np.unique(pr_image_sbu, axis=0))==1 and len(np.unique(pr_image_organic, axis=0))==1): # linker 
@@ -494,11 +502,13 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     """""""""
     if len(linker_subgraphlist)>=1: #Featurize cases that did not fail
         try:
+        # if True:
             descriptor_names, descriptors, lc_descriptor_names, lc_descriptors = make_MOF_SBU_RACs(SBU_list, SBU_subgraphlist, molcif, depth, name , cell_v,anc_atoms, sbupath, connections_list, connections_subgraphlist)
             lig_descriptor_names, lig_descriptors = make_MOF_linker_RACs(linker_list, linker_subgraphlist, molcif, depth, name, cell_v, linkerpath)
             full_names = descriptor_names+lig_descriptor_names+lc_descriptor_names #+ ECFP_names
             full_descriptors = list(descriptors)+list(lig_descriptors)+list(lc_descriptors)
             print(len(full_names),len(full_descriptors))
+        # else:
         except:
             full_names = [0]
             full_descriptors = [0]
@@ -518,17 +528,16 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
 
 ##### Example of usage over a set of cif files.
 # featurization_list = []
-# for cif_file in os.listdir('<your base directory here>/cif/'):
+# import sys
+# featurization_directory = sys.argv[1]
+# for cif_file in os.listdir(featurization_directory+'/cif/'):
 #     #### This first part gets the primitive cells ####
-#     get_primitive('<your base directory here>/cif/'+cif_file, '<your base directory here>/primitive/'+cif_file)
-#     full_names, full_descriptors = get_MOF_descriptors('<your base directory here>/primitive/'+cif_file,3,path='<your base directory here>/structures/',
-#         xyzpath='<your base directory here>/structures/xyz/'+cif_file.replace('cif','xyz'))
+#     get_primitive(featurization_directory+'/cif/'+cif_file, featurization_directory+'/primitive/'+cif_file)
+#     full_names, full_descriptors = get_MOF_descriptors(featurization_directory+'/primitive/'+cif_file,3,path=featurization_directory+'/',
+#         xyzpath=featurization_directory+'/xyz/'+cif_file.replace('cif','xyz'))
 #     full_names.append('filename')
 #     full_descriptors.append(cif_file)
 #     featurization = dict(zip(full_names, full_descriptors))
 #     featurization_list.append(featurization)
 # df = pd.DataFrame(featurization_list) 
-# df = pd.DataFrame(featurization_list) 
-# keep = [val for val in df.columns.values if ('mc' in val) or ('lc' in val) or ('f-lig' in val) or ('func') in val]
-# df = df[['filename']+keep] ### this gets the 156 RACs reported in the paper. SBU Racs are redundant with mc RACs and are not included.
-# df.to_csv('./full_featurization_frame.csv',index=False) 
\ No newline at end of file
+# df.to_csv('./full_featurization_frame.csv',index=False) 
