@@ -1,30 +1,38 @@
-import glob
-import string
-import sys
-import os
 import numpy as np
-import math
-import random
-from molSimplify.Scripts.geometry import *
-from molSimplify.Classes.atom3D import *
-from molSimplify.Classes.globalvars import globalvars
-from molSimplify.Classes.mol3D import *
-from molSimplify.Classes.ligand import *
 from molSimplify.Classes.ligand import ligand_breakdown, ligand_assign
+from molSimplify.Scripts.geometry import distance
+from molSimplify.Classes.globalvars import globalvars
 
 ########### UNIT CONVERSION
 HF_to_Kcal_mol = 627.503
 
 
 def autocorrelation(mol, prop_vec, orig, d, oct=True, catoms=None, use_dist=False):
-    ## this function returns the autocorrelation
-    ## for one atom
-    # Inputs:
-    #	mol - mol3D class
-    #	prop_vec - vector, property of atoms in mol in order of index
-    #	orig -  int, zero-indexed starting atom
-    #	d - int, number of hops to travel
-    #	oct - bool, if complex is octahedral, will use better bond checks
+    """Calculate and return the products autocorrelation for a single atom
+
+    Parameters
+    ----------
+        mol : mol3D
+            mol3D object to calculate autocorrelation over
+        prop_vec : list
+            property of atoms in mol in order of index
+        orig : int
+            zero-indexed starting atom
+        d : int
+            number of hops to travel
+        oct : bool, optional
+            Flag is octahedral complex, by default True
+        catoms: list, optional
+            List of connecting atoms, by default None (uses mol3D.getBondedAtomsSmart)
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+
+    Returns
+    -------
+        result_vector : list
+            assembled products autocorrelations
+
+    """
     result_vector = np.zeros(d + 1)
     hopped = 0
     active_set = set([orig])
@@ -57,20 +65,28 @@ def autocorrelation(mol, prop_vec, orig, d, oct=True, catoms=None, use_dist=Fals
 
 
 def autocorrelation_derivative(mol, prop_vec, orig, d, oct=True, catoms=None):
-    ## this function returns the derivative vector
-    ## of the scalar autocorrelation 
-    ## starting at orig with depth d,
-    ## with respect to the atomic properties
-    ## in prop_vec, for all atoms.
-    ## The return type is np.array
-    ## Be sure to read this carefully!
-    ## for one atom
-    # Inputs:
-    #	mol - mol3D class
-    #	prop_vec - vector, property of atoms in mol in order of index
-    #	orig -  int, zero-indexed starting atom
-    #	d - int, number of hops to travel
-    #	oct - bool, if complex is octahedral, will use better bond checks
+    """Returns derivative vector of products autocorrelations
+
+    Parameters
+    ----------
+        mol : mol3D
+            mol3D object to calculate derivatives over
+        prop_vec : list
+            property of atoms in mol in order of index
+        orig : int
+            zero-indexed starting atom
+        d : int
+            number of hops to travel
+        oct : bool, optional
+            Flag is octahedral complex, by default True
+        catoms : list, optional
+            List of connecting atom, by default None (use mol3D.getBondedAtomsSmart)
+    Returns
+    -------
+        derivative_mat : list
+            RAC derivatives matrix
+
+    """
     derivative_mat = np.zeros((d + 1, len(prop_vec)))
 
     # loop for each atom
@@ -107,23 +123,32 @@ def autocorrelation_derivative(mol, prop_vec, orig, d, oct=True, catoms=None):
 
 
 def ratiometric(mol, prop_vec_num, prop_vec_den, orig, d, oct=True, catoms=None):
-    ## this function returns the ratiometrics
-    ## for one atom
-    # Inputs:
-    #	mol - mol3D class
-    #	prop_vec - vector, property of atoms in mol in order of index
-    #	orig -  int, zero-indexed starting atom
-    #	d - int, number of hops to travel
-    #	oct - bool, if complex is octahedral, will use better bond checks
+    """This function returns the ratiometrics for one atom
+    
+    Parameters
+    ----------
+        mol : mol3D class
+        prop_vec : vector, property of atoms in mol in order of index
+        orig : int, zero-indexed starting atom
+        d : int, number of hops to travel
+        oct : bool, if complex is octahedral, will use better bond checks
+    
+    Returns
+    -------
+        result_vector : vector of prop_vec_num / prop_vec_den
+    
+    """
     result_vector = np.zeros(d + 1)
     hopped = 0
     active_set = set([orig])
     historical_set = set()
     result_vector[hopped] = prop_vec_num[orig] / prop_vec_den[orig]
-    #	if oct:
-    #		print('using OCT autocorrelation')
-    #	#else:
-    #		print('NOT using OCT autocorrelation')
+    """
+        if oct:
+            print('using OCT autocorrelation')
+        else:
+            print('NOT using OCT autocorrelation')
+    """
     while hopped < (d):
 
         hopped += 1
@@ -144,23 +169,32 @@ def ratiometric(mol, prop_vec_num, prop_vec_den, orig, d, oct=True, catoms=None)
 
 
 def summetric(mol, prop_vec, orig, d, oct=True, catoms=None):
-    ## this function returns the summetrics
-    ## for one atom
-    # Inputs:
-    #	mol - mol3D class
-    #	prop_vec - vector, property of atoms in mol in order of index
-    #	orig -  int, zero-indexed starting atom
-    #	d - int, number of hops to travel
-    #	oct - bool, if complex is octahedral, will use better bond checks
+    """This function returns the summetrics for one atom
+    
+    Parameters
+    ----------
+        mol : mol3D class
+        prop_vec : vector, property of atoms in mol in order of index
+        orig : int, zero-indexed starting atom
+        d : int, number of hops to travel
+        oct : bool, if complex is octahedral, will use better bond checks
+        
+    Returns
+    -------
+        result_vector : vector of prop_vec_num / prop_vec_den
+
+    """
     result_vector = np.zeros(d + 1)
     hopped = 0
     active_set = set([orig])
     historical_set = set()
     result_vector[hopped] = prop_vec[orig] + prop_vec[orig]
-    #	if oct:
-    #		print('using OCT autocorrelation')
-    #	#else:
-    #		print('NOT using OCT autocorrelation')
+    """   
+        if oct:
+            print('using OCT autocorrelation')
+        else:
+            print('NOT using OCT autocorrelation')
+    """
     while hopped < (d):
 
         hopped += 1
@@ -609,7 +643,7 @@ def construct_property_vector(mol, prop, oct=True, modifier=False):
     ##             ONLY used with  ox_nuclear_charge    ox or charge)
     ##              {"Fe":2, "Co": 3} etc
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology',
-                       'ox_nuclear_charge', 'size', 'vdwrad', 'effective_nuclear_charge', 'polarizability',
+                       'ox_nuclear_charge', 'size', 'vdwrad', 'group_number', 'polarizability',
                        'bondvalence', 'num_bonds', 'bondvalence_devi', 'bodavrg', 'bodstd', 'charge']
     ## note that ident just codes every atom as one, this gives
     ## a purely toplogical index. coord gives the number of
@@ -636,13 +670,13 @@ def construct_property_vector(mol, prop, oct=True, modifier=False):
         for keys in at_keys:
             values = globs.amass()[keys][1]
             prop_dict.update({keys: values})
-    elif prop == 'effective_nuclear_charge':  # Uses number of valence electrons
+    elif prop == 'group_number':  # Uses number of valence electrons
         # if not modifier:
         at_keys = list(globs.amass().keys())
         for keys in at_keys:
-            values = globs.amass()[keys][0]
+            values = globs.amass()[keys][-1]
             prop_dict.update({keys: values}) 
-        ####### 11/06/2019 -- Adjusted Zeff RACs to not adjust on oxidation state. Confounded with O RACs. #####
+        ####### 11/06/2019 -- Adjusted Gval RACs to not adjust on oxidation state. Confounded with O RACs. #####
         # # else:
         #     at_keys = globs.amass().keys()
         #     for keys in at_keys:
@@ -1054,15 +1088,15 @@ def find_mc_eq_ax_autocorrelation_oct(mol, prop, loud, depth, name=False, oct=Tr
 
 
 def generate_mc_eq_ax_deltametrics(mol, loud, depth=4, name=False,
-                                   func=deltametric_catoms, NumB=False, Zeff=False):
+                                   func=deltametric_catoms, NumB=False, Gval=False):
     result_ax_mc = list()
     result_eq_mc = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1081,15 +1115,15 @@ def generate_mc_eq_ax_deltametrics(mol, loud, depth=4, name=False,
 
 
 def generate_mc_eq_ax_autocorrelation(mol, loud, depth=4, name=False,
-                                      func=autocorrelation_catoms, NumB=False, Zeff=False):
+                                      func=autocorrelation_catoms, NumB=False, Gval=False):
     result_ax_mc = list()
     result_eq_mc = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1108,7 +1142,7 @@ def generate_mc_eq_ax_autocorrelation(mol, loud, depth=4, name=False,
 
 
 def generate_all_ligand_autocorrelations(mol, loud, depth=4, name=False, flag_name=False,
-                                         custom_ligand_dict=False, NumB=False, Zeff=False):
+                                         custom_ligand_dict=False, NumB=False, Gval=False):
     ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
     ##                                    ax_con_int_list ,eq_con_int_list
     ## with types: eq/ax_ligand_list list of mol3D
@@ -1120,9 +1154,9 @@ def generate_all_ligand_autocorrelations(mol, loud, depth=4, name=False, flag_na
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+=['effective_nuclear_charge']
-        labels_strings += ['Zeff']
+    if Gval:
+        allowed_strings+=['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1153,7 +1187,7 @@ def generate_all_ligand_autocorrelations(mol, loud, depth=4, name=False, flag_na
 
 
 def generate_all_ligand_autocorrelation_derivatives(mol, loud, depth=4, name=False, flag_name=False,
-                                                    custom_ligand_dict=False, NumB=False, Zeff=False):
+                                                    custom_ligand_dict=False, NumB=False, Gval=False):
     ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
     ##                                    ax_con_int_list ,eq_con_int_list
     ## with types: eq/ax_ligand_list list of mol3D
@@ -1166,9 +1200,9 @@ def generate_all_ligand_autocorrelation_derivatives(mol, loud, depth=4, name=Fal
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1215,7 +1249,7 @@ def generate_all_ligand_autocorrelation_derivatives(mol, loud, depth=4, name=Fal
 
 
 def generate_all_ligand_autocorrs_and_deltametrics_dimers(mol, loud, depth=4, name=False, flag_name=False,
-                                                          custom_ligand_dict=False, NumB=False, Zeff=False):
+                                                          custom_ligand_dict=False, NumB=False, Gval=False):
     ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
     ##                                    ax_con_int_list ,eq_con_int_list
     ## with types: eq/ax_ligand_list list of mol3D
@@ -1233,9 +1267,9 @@ def generate_all_ligand_autocorrs_and_deltametrics_dimers(mol, loud, depth=4, na
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1284,7 +1318,7 @@ def generate_all_ligand_autocorrs_and_deltametrics_dimers(mol, loud, depth=4, na
 
 
 def generate_all_ligand_deltametrics(mol, loud, depth=4, name=False, flag_name=False,
-                                     custom_ligand_dict=False, NumB=False, Zeff=False):
+                                     custom_ligand_dict=False, NumB=False, Gval=False):
     ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
     ##                                    ax_con_int_list ,eq_con_int_list
     ## with types: eq/ax_ligand_list list of mol3D
@@ -1295,9 +1329,9 @@ def generate_all_ligand_deltametrics(mol, loud, depth=4, name=False, flag_name=F
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1319,7 +1353,7 @@ def generate_all_ligand_deltametrics(mol, loud, depth=4, name=False, flag_name=F
 
 
 def generate_all_ligand_deltametric_derivatives(mol, loud, depth=4, name=False, flag_name=False,
-                                                custom_ligand_dict=False, NumB=False, Zeff=False):
+                                                custom_ligand_dict=False, NumB=False, Gval=False):
     ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
     ##                                    ax_con_int_list ,eq_con_int_list
     ## with types: eq/ax_ligand_list list of mol3D
@@ -1330,9 +1364,9 @@ def generate_all_ligand_deltametric_derivatives(mol, loud, depth=4, name=False,
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1361,15 +1395,15 @@ def generate_all_ligand_deltametric_derivatives(mol, loud, depth=4, name=False,
 
 
 def generate_metal_autocorrelations(mol, loud, depth=4, oct=True, flag_name=False,
-                                    modifier=False, NumB=False, Zeff=False):
+                                    modifier=False, NumB=False, Gval=False):
     #	oct - bool, if complex is octahedral, will use better bond checks
     result = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1388,15 +1422,15 @@ def generate_metal_autocorrelations(mol, loud, depth=4, oct=True, flag_name=Fals
 
 
 def generate_metal_autocorrelation_derivatives(mol, loud, depth=4, oct=True, flag_name=False,
-                                               modifier=False, NumB=False, Zeff=False):
+                                               modifier=False, NumB=False, Gval=False):
     #	oct - bool, if complex is octahedral, will use better bond checks
     result = None
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1418,12 +1452,15 @@ def generate_metal_autocorrelation_derivatives(mol, loud, depth=4, oct=True, fla
     return results_dictionary
 
 
-def generate_multimetal_autocorrelations(mol, loud, depth=4, oct=True, flag_name=False, polarizability=False):
+def generate_multimetal_autocorrelations(mol, loud, depth=4, oct=True, flag_name=False, polarizability=False, Gval=False):
     #	oct - bool, if complex is octahedral, will use better bond checks
     result = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if polarizability:
         allowed_strings += ['polarizability']
         labels_strings += ['alpha']
@@ -1532,10 +1569,10 @@ def generate_metal_ox_eff_autocorrelations(oxmodifier, mol, loud, depth=4, oct=T
     #   oct - bool, if complex is octahedral, will use better bond checks
     result = list()
     colnames = []
-    metal_ox_ac = metal_only_autocorrelation(mol, 'effective_nuclear_charge', depth, oct=oct, modifier=oxmodifier)
+    metal_ox_ac = metal_only_autocorrelation(mol, 'group_number', depth, oct=oct, modifier=oxmodifier)
     this_colnames = []
     for i in range(0, depth + 1):
-        this_colnames.append('Zeff' + '-' + str(i))
+        this_colnames.append('Gval' + '-' + str(i))
     colnames.append(this_colnames)
     result.append(metal_ox_ac)
     results_dictionary = {'colnames': colnames, 'results': result}
@@ -1549,10 +1586,10 @@ def generate_metal_ox_eff_deltametrics(oxmodifier, mol, loud, depth=4, oct=True,
     #   oct - bool, if complex is octahedral, will use better bond checks
     result = list()
     colnames = []
-    metal_ox_ac = metal_only_deltametric(mol, 'effective_nuclear_charge', depth, oct=oct, modifier=oxmodifier)
+    metal_ox_ac = metal_only_deltametric(mol, 'group_number', depth, oct=oct, modifier=oxmodifier)
     this_colnames = []
     for i in range(0, depth + 1):
-        this_colnames.append('Zeff' + '-' + str(i))
+        this_colnames.append('Gval' + '-' + str(i))
     colnames.append(this_colnames)
     result.append(metal_ox_ac)
     results_dictionary = {'colnames': colnames, 'results': result}
@@ -1560,15 +1597,15 @@ def generate_metal_ox_eff_deltametrics(oxmodifier, mol, loud, depth=4, oct=True,
 
 
 def generate_metal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False,
-                                modifier=False, NumB=False, Zeff=False):
+                                modifier=False, NumB=False, Gval=False):
     #	oct - bool, if complex is octahedral, will use better bond checks
     result = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1587,15 +1624,15 @@ def generate_metal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False,
 
 
 def generate_metal_deltametric_derivatives(mol, loud, depth=4, oct=True, flag_name=False,
-                                           modifier=False, NumB=False, Zeff=False):
+                                           modifier=False, NumB=False, Gval=False):
     #	oct - bool, if complex is octahedral, will use better bond checks
     result = None
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings += ['effective_nuclear_charge']
-        labels_strings += ['Zeff']
+    if Gval:
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1616,12 +1653,15 @@ def generate_metal_deltametric_derivatives(mol, loud, depth=4, oct=True, flag_na
     return results_dictionary
 
 
-def generate_multimetal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False, polarizability=False):
+def generate_multimetal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False, polarizability=False,Gval=False):
     #	oct - bool, if complex is octahedral, will use better bond checks
     result = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if polarizability:
         allowed_strings += ['polarizability']
         labels_strings += ['alpha']
@@ -1661,14 +1701,14 @@ def generate_multiatom_deltametrics(mol, loud, depth=4, oct=True, flag_name=Fals
 def generate_full_complex_autocorrelations(mol, loud,
                                            depth=4, oct=True,
                                            flag_name=False, modifier=False,
-                                           use_dist=False, NumB=False, Zeff=False, polarizability=False):
+                                           use_dist=False, NumB=False, Gval=False, polarizability=False):
     result = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1700,8 +1740,8 @@ def generate_full_complex_coulomb_autocorrelations(mol, loud,
     # allowed_strings = ['ident', 'topology', 'bondvalence', 'valenceelectron', 'bondvalence_devi', 'bodavrg', 'bodstd',
     #                    'charge']
     # labels_strings = ['I', 'T', 'BV', 'VE', 'BVD', "BODavrg", "BODstd", "Ch"]
-    allowed_strings = ['ident', 'topology', 'effective_nuclear_charge', "num_bonds"]
-    labels_strings = ['I', 'T', 'Zeff', "NumB"]
+    allowed_strings = ['ident', 'topology', 'group_number', "num_bonds"]
+    labels_strings = ['I', 'T', 'Gval', "NumB"]
     for ii, properties in enumerate(allowed_strings):
         metal_ac = full_autocorrelation(mol, properties, depth,
                                         oct=oct, modifier=modifier,
@@ -1719,14 +1759,14 @@ def generate_full_complex_coulomb_autocorrelations(mol, loud,
 
 
 def generate_full_complex_autocorrelation_derivatives(mol, loud, depth=4, oct=True, flag_name=False,
-                                                      modifier=False, NumB=False, Zeff=False):
+                                                      modifier=False, NumB=False, Gval=False):
     result = None
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1748,7 +1788,7 @@ def generate_full_complex_autocorrelation_derivatives(mol, loud, depth=4, oct=Tr
     return results_dictionary
 
 
-def generate_atomonly_autocorrelations(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Zeff = False, polarizability=False):
+def generate_atomonly_autocorrelations(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Gval = False, polarizability=False):
     ## this function gets autocorrelations for a molecule starting
     ## in one single atom only
     # Inputs:
@@ -1759,9 +1799,9 @@ def generate_atomonly_autocorrelations(mol, atomIdx, loud, depth=4, oct=True, Nu
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings += ['effective_nuclear_charge']
-        labels_strings += ['Zeff']
+    if Gval:
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1780,7 +1820,7 @@ def generate_atomonly_autocorrelations(mol, atomIdx, loud, depth=4, oct=True, Nu
     return results_dictionary
 
 
-def generate_atomonly_autocorrelation_derivatives(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Zeff=False):
+def generate_atomonly_autocorrelation_derivatives(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Gval=False):
     ## this function gets the d/dx for autocorrelations for a molecule starting
     ## in one single atom only
     # Inputs:
@@ -1791,9 +1831,9 @@ def generate_atomonly_autocorrelation_derivatives(mol, atomIdx, loud, depth=4, o
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1812,7 +1852,7 @@ def generate_atomonly_autocorrelation_derivatives(mol, atomIdx, loud, depth=4, o
     return results_dictionary
 
 
-def generate_atomonly_deltametrics(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Zeff=False, polarizability=False):
+def generate_atomonly_deltametrics(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Gval=False, polarizability=False):
     ## this function gets deltametrics for a molecule starting
     ## in one single atom only
     # Inputs:
@@ -1823,9 +1863,9 @@ def generate_atomonly_deltametrics(mol, atomIdx, loud, depth=4, oct=True, NumB=F
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings += ['effective_nuclear_charge']
-        labels_strings += ['Zeff'] 
+    if Gval:
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval'] 
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -1844,7 +1884,7 @@ def generate_atomonly_deltametrics(mol, atomIdx, loud, depth=4, oct=True, NumB=F
     return results_dictionary
 
 
-def generate_atomonly_deltametric_derivatives(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Zeff=False):
+def generate_atomonly_deltametric_derivatives(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Gval=False):
     ## this function gets deltametrics for a molecule starting
     ## in one single atom only
     # Inputs:
@@ -1855,9 +1895,9 @@ def generate_atomonly_deltametric_derivatives(mol, atomIdx, loud, depth=4, oct=T
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
-    if Zeff:
-        allowed_strings+= ['effective_nuclear_charge']
-        labels_strings+= ['Zeff']
+    if Gval:
+        allowed_strings+= ['group_number']
+        labels_strings+= ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
