@@ -4,22 +4,29 @@
 
 
 # import standard modules
-import os, sys
-from pkg_resources import resource_filename, Requirement
-import openbabel, random, itertools
-from numpy import log, arccos, cross, dot, pi
 
 # molS modules
-from molSimplify.Classes.globalvars import *
-from molSimplify.Classes.mol3D import *
-from molSimplify.Scripts.geometry import *
-from molSimplify.Scripts.molSimplify_io import *
-import molSimplify.Scripts.structgen ## this is needed for circlular 
-                                     ## FF dependence
+from molSimplify.Classes.mol3D import mol3D
+from molSimplify.Scripts.geometry import (checkcolinear,
+                                          distance,
+                                          norm,
+                                          rotate_around_axis,
+                                          rotation_params,
+                                          vecangle,
+                                          vecdiff)
+from molSimplify.Scripts.io import getlicores, lig_load
+
+## FF dependence
 ##########################################
 ####### ligand decoration function #######
-##########################################    
+##########################################
+
+
+
 def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
+    # structgen depends on decoration_manager, and decoration_manager depends on structgen.ffopt
+    # Thus, this import needs to be placed here to avoid a circular dependence
+    from molSimplify.Scripts.structgen import ffopt
     # INPUT
     #   - args: placeholder for input arguments
     #   - ligand_to_decorate: mol3D ligand
@@ -56,6 +63,7 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
         print(('** decoration number ' +str(i)+ ' attaching ' + dec + ' at site '+str(decoration_index[i]) 
     + '**\n'))
         dec,emsg = lig_load(dec,licores)
+        # dec.OBMol.AddHydrogens()
         dec.convert2mol3D() # convert to mol3D
         if args.debug:
             print(i)
@@ -66,14 +74,17 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
             merged_ligand.writexyz('basic.xyz')
         #dec.writexyz('dec' + str(i) + '.xyz')
         Hs = dec.getHsbyIndex(0)
-        if len(Hs) > 0:
+        if len(Hs) > 0 and (not len(dec.cat)):
             dec.deleteatom(Hs[0])
             dec.charge = dec.charge - 1
 
         #dec.writexyz('dec_noH' + str(i) + '.xyz')
-        
-        dec.alignmol(dec.getAtom(0),merged_ligand.getAtom(decoration_index[i]))
-        r1 = dec.getAtom(0).coords()
+        if len(dec.cat) > 0:
+            decind = dec.cat[0]
+        else:
+            decind = 0
+        dec.alignmol(dec.getAtom(decind),merged_ligand.getAtom(decoration_index[i]))
+        r1 = dec.getAtom(decind).coords()
         r2 = dec.centermass() # center of mass
         rrot = r1
         decb = mol3D()
@@ -81,7 +92,7 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
         ####################################
         # center of mass of local environment (to avoid bad placement of bulky ligands)
         auxmol = mol3D()
-        for at in dec.getBondedAtoms(0):
+        for at in dec.getBondedAtoms(decind):
             auxmol.addAtom(dec.getAtom(at))
         if auxmol.natoms > 0:
             r2 = auxmol.centermass() # overwrite global with local centermass
@@ -97,14 +108,14 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
                 decb.writexyz('dec_ARB' + str(i) + '.xyz')
             d1 = distance(dec.centermass(),merged_ligand.centermass())
             d2 = distance(decb.centermass(),merged_ligand.centermass())
-            dec = dec if (d2 < d1)  else decb # pick best one
+            dec = dec if (d2 < d1) else decb # pick best one
         #####################################
         # check for linear molecule
         auxm = mol3D()
-        for at in dec.getBondedAtoms(0):
+        for at in dec.getBondedAtoms(decind):
             auxm.addAtom(dec.getAtom(at))
         if auxm.natoms > 1:
-            r0 = dec.getAtom(0).coords()
+            r0 = dec.getAtom(decind).coords()
             r1 = auxm.getAtom(0).coords()
             r2 = auxm.getAtom(1).coords()
             if checkcolinear(r1,r0,r2):
@@ -114,14 +125,14 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
                 
         ## get the default distance between atoms in question 
         connection_neighbours = merged_ligand.getAtom(merged_ligand.getBondedAtomsnotH(decoration_index[i])[0])
-        new_atom = dec.getAtom(0)
+        new_atom = dec.getAtom(decind)
         target_distance = connection_neighbours.rad + new_atom.rad 
         position_to_place = vecdiff(new_atom.coords(),connection_neighbours.coords())
         old_dist= norm(position_to_place)
         missing = (target_distance - old_dist)/2
         dec.translate([missing*position_to_place[j] for j in [0,1,2]])
         
-        r1 = dec.getAtom(0).coords()
+        r1 = dec.getAtom(decind).coords()
         u = vecdiff(r1,merged_ligand.getAtom(decoration_index[i]).coords())
         dtheta = 2
         optmax = -9999
@@ -149,13 +160,13 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
         if args.debug:
             dec.writexyz('dec_aligned' + str(i) + '.xyz')
             print(('natoms before delete ' + str(merged_ligand.natoms)))
-            print(('obmol before delete at  ' + str(decoration_index[i]) + ' is '  + str(merged_ligand.OBMol.NumAtoms())))
+            print(('obmol before delete at  ' + str(decoration_index[i]) + ' is ' + str(merged_ligand.OBMol.NumAtoms())))
         ## store connectivity for deleted H
         BO_mat = merged_ligand.populateBOMatrix()
         row_deleted = BO_mat[decoration_index[i]]
-        bonds_to_add  = []
+        bonds_to_add = []
         
-        # find where to put the new bonds
+        # find where to put the new bonds ->>> Issue here.
         for j,els in enumerate(row_deleted):
             if els > 0:
                 # if there is a bond with an atom number
@@ -165,7 +176,10 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
                     bond_partner = j
                 else:
                     bond_partner = j -1
-                bonds_to_add.append((bond_partner,merged_ligand.natoms-1,els))
+                if len(dec.cat) > 0:
+                    bonds_to_add.append((bond_partner,(merged_ligand.natoms-1)+dec.cat[0],els))
+                else:
+                    bonds_to_add.append((bond_partner,merged_ligand.natoms-1,els))
         
         ## perfrom delete
         merged_ligand.deleteatom(decoration_index[i])
@@ -183,10 +197,9 @@ def decorate_ligand(args,ligand_to_decorate,decoration,decoration_index):
             print('************')
     
     merged_ligand.convert2OBMol()
-    merged_ligand,emsg = molSimplify.Scripts.structgen.ffopt('MMFF94',merged_ligand,[],0,[],False,[],100)
+    merged_ligand,emsg = ffopt('MMFF94',merged_ligand,[],0,[],False,[],100)
     BO_mat = merged_ligand.populateBOMatrix()
     if args.debug:
         merged_ligand.writexyz('merged_relaxed.xyz')
         print(BO_mat)    
     return(merged_ligand)
-    
