@@ -6,23 +6,45 @@
 #  Dpt of Chemical Engineering, MIT
 
 import os
-import sys
-import copy
-import glob
-import re
-import math
 import random
-import string
+import copy
 import numpy
-from math import pi
-from scipy.spatial import Delaunay, ConvexHull
-from molSimplify.Scripts.geometry import *
-from molSimplify.Classes.atom3D import *
-from molSimplify.Classes.mol3D import*
+from math import sqrt
+
+from scipy.spatial import Delaunay
+from molSimplify.Classes.atom3D import atom3D
+from molSimplify.Classes.mol3D import mol3D
 from molSimplify.Classes.globalvars import globalvars
-from operator import add
-from molSimplify.Scripts.periodic_QE import *
-from molSimplify.Scripts.cellbuilder_tools import *
+from molSimplify.Scripts.cellbuilder_tools import (cell_ffopt,
+                                                   center_of_sym,
+                                                   check_top_layer_correct,
+                                                   closest_torus_point,
+                                                   distance_2d_torus,
+                                                   evaluate_basis_coefficients,
+                                                   find_all_surface_atoms,
+                                                   find_extents,
+                                                   find_extents_cv,
+                                                   freeze_bottom_n_layers,
+                                                   get_basis_coefficients,
+                                                   import_from_cif,
+                                                   mdistance,
+                                                   normalize_vector,
+                                                   periodic_mindist,
+                                                   periodic_selfdist,
+                                                   shave_surface_layer,
+                                                   shave_under_layer,
+                                                   threshold_basis,
+                                                   xgcd,
+                                                   zero_z)
+from molSimplify.Scripts.geometry import (PointRotateAxis,
+                                          checkcolinear,
+                                          vecdiff,
+                                          rotate_around_axis,
+                                          rotation_params,
+                                          vecangle,
+                                          distance)
+from molSimplify.Scripts.periodic_QE import (write_periodic_mol3d_to_qe)
+
 
 ###############################
 
@@ -41,9 +63,6 @@ def d_fix(unit_cell, cell_vector):
             minind = i
             print('this was saved')
         print("\n\n")
-    a = cell_vector[0]
-
-    b = cell_vector[1]
     c = cell_vector[2]
     dx = c[0]
     dy = c[1]
@@ -61,10 +80,10 @@ def cut_cell_to_index(unit_cell, cell_vector, miller_index):
     # determine the plane:
     cut_cell = mol3D()
     cut_cell.copymol3D(unit_cell)
-    h, k, l = miller_index
-    #print('h,k,l',str(h) + ' ' + str(k) +  ' ' +  str(l))
+    h, k, l = miller_index  # noqa: E741
+    # print('h,k,l',str(h) + ' ' + str(k) +  ' ' +  str(l))
     disc, p, q = xgcd(k, l)
-    #print('p,q',str(p) + ' ' + str(q))
+    # print('p,q',str(p) + ' ' + str(q))
     cell_vector = numpy.array(cell_vector)
     k1 = numpy.dot(p*(k*cell_vector[0]-h*cell_vector[1]) + q*(
         l*cell_vector[0] - h*cell_vector[2]), l*cell_vector[1] - k*cell_vector[2])
@@ -93,18 +112,18 @@ def cut_cell_to_index(unit_cell, cell_vector, miller_index):
 
     print(('nz ind', non_zero_indices))
     if len(non_zero_indices) == 3:
-        zint = 1/(miller_index[2]*cell_vector[2][2])
-        yint = 1/(miller_index[1]*cell_vector[1][1])
-        xint = 1/(miller_index[0]*cell_vector[0][0])
-        #w = [0,0,0]
+        # zint = 1/(miller_index[2]*cell_vector[2][2])
+        # yint = 1/(miller_index[1]*cell_vector[1][1])
+        # xint = 1/(miller_index[0]*cell_vector[0][0])
+        # w = [0,0,0]
         # w[2] = zint
-        #w[1] = -w[2]/yint
-        #w[0] = -w[2]/xint
+        # w[1] = -w[2]/yint
+        # w[0] = -w[2]/xint
         plane_normal = numpy.cross(v1, v2)
     elif len(non_zero_indices) == 2:
-      #      print('\n\n\n\n')
-       #     print(cell_vector)
-       #     print("\n\n")
+        # print('\n\n\n\n')
+        # print(cell_vector)
+        # print("\n\n")
         vec1 = [0, 0, 0]
         vec1[non_zero_indices[0]] = cell_vector[non_zero_indices[0]
                                                 ][non_zero_indices[0]]
@@ -113,9 +132,9 @@ def cut_cell_to_index(unit_cell, cell_vector, miller_index):
                                                 ][non_zero_indices[1]]
         vec3 = [0, 0, 0]
         vec3[zero_indices[0]] = cell_vector[zero_indices[0]][zero_indices[0]]
-     #   print('vec1',vec1)
-     #   print('vec2',vec2)
-     #   print('vec3',vec3)
+        # print('vec1',vec1)
+        # print('vec2',vec2)
+        # print('vec3',vec3)
         plane_normal = numpy.cross(v1, v2)
     elif len(non_zero_indices) == 1:
 
@@ -136,8 +155,8 @@ def concave_hull(points, alpha):
     # points should be tuples
     de = Delaunay(points)
     for i in de.simplices:
-        tmp = []
-        j = [points[c] for c in i]
+        tmp = []  # noqa F841 WIP
+        j = [points[c] for c in i]  # noqa F841 WIP
     #    print(i)
     #    print(j)
     # print(de)
@@ -163,9 +182,6 @@ def unit_to_super(unit_cell, cell_vector, duplication_vector):
     a = cell_vector[0]
     b = cell_vector[1]
     c = cell_vector[2]
-#        print('.......................................')
-#        print(atoms.symbol())
-#        print(atoms.coords())
     for i in range(0, acell):
         for j in range(0, bcell):
             for k in range(0, ccell):
@@ -195,8 +211,8 @@ def multialign_objective_function(payload, surface_coord_list, cand_list, bind_d
     #   - cost: float, sum of squared error, the difference between
     #           the actual distance and the target
     cost = 0
-    #print('cand list is ' + str(cand_list))
-    #print('surface_coord_list  ' + str(surface_coord_list))
+    # print('cand list is ' + str(cand_list))
+    # print('surface_coord_list  ' + str(surface_coord_list))
     for indices in enumerate(cand_list):
         v1 = (surface_coord_list[indices[0]])
         v2 = payload.getAtom(int(indices[1])).coords()
@@ -282,7 +298,7 @@ def choose_nearest_neighbour(target_site, avail_sites_dict, occupied_sites_dict,
     # OUPUT
     #   - nn_site: index of nearest neighbour  site, a key for avail_sites_dict
     extents = find_extents_cv(super_cell_vector)
- #   print('extents = ' + str(extents))
+    # print('extents = ' + str(extents))
     weight = 0  # favours adjaceny to point over distance from other occupied sites
     # get the nearest site to target
     score = 100000  # weighted assessment, lower is better
@@ -338,7 +354,6 @@ def choose_best_site(avail_sites_dict, occupied_sites_dict, centroid, super_cell
     #   - target_site: index of target site, a key for avail_sites_dict
     extents = find_extents_cv(super_cell_vector)
     centroid = surface_center(super_cell)
-    skipalign = 0
     score = 100000  # weighted assessment, lower is better
     avail_sites_list = list(avail_sites_dict.keys())
     random.shuffle(avail_sites_list)
@@ -352,7 +367,7 @@ def choose_best_site(avail_sites_dict, occupied_sites_dict, centroid, super_cell
         print(('weight = ' + str(weight)))
     if (len(avail_sites_list) > 1):  # more than 1 option, pick closest to center of plane
         for indices in avail_sites_list:
-            #distance_to_center =  distance_2d_torus(centroid,avail_sites_dict[indices],extents)
+            # distance_to_center =  distance_2d_torus(centroid,avail_sites_dict[indices],extents)
             distance_to_center = distance(centroid, avail_sites_dict[indices])
 
             distance_to_nearest_occupied = 1000
@@ -403,7 +418,7 @@ def align_payload_to_multi_site(payload, surface_coord_list, cand_list, bind_dis
     #                  align_coord. )Does NOT change height
 
     # Get all atoms on the top surface - NB, this will not handle complex surfaces, split calls by atom type
-    #print('align symbol is ' + payload.getAtom(cand_ind).symbol())
+    # print('align symbol is ' + payload.getAtom(cand_ind).symbol())
     new_payload = mol3D()
     new_payload.copymol3D(payload)
     payload_coord = center_of_sym(
@@ -439,7 +454,7 @@ def align_payload_to_multi_site(payload, surface_coord_list, cand_list, bind_dis
         ), new_payload.getAtom(cand_list[1]).coords(), new_payload.getAtom(cand_list[2]).coords())
     elif len(cand_list) == 4:
         pass
-        #coplanar_flag = checkplanar(new_payload.getAtom(cand_list[0]),new_payload.getAtom(cand_list[1]),new_payload.getAtom(cand_list[2]),new_payload.getAtom(cand_list[3]).coords())
+        # coplanar_flag = checkplanar(new_payload.getAtom(cand_list[0]),new_payload.getAtom(cand_list[1]),new_payload.getAtom(cand_list[2]),new_payload.getAtom(cand_list[3]).coords())
     if collinear_flag:  # there is a single line defining the axis - align this with
         line_slope = vecdiff(new_payload.getAtom(
             cand_list[0]).coords(), new_payload.getAtom(cand_list[1]).coords())
@@ -467,7 +482,7 @@ def align_payload_to_multi_site(payload, surface_coord_list, cand_list, bind_dis
             this_cost = multialign_objective_function(
                 this_payload, surface_coord_list, cand_list, bind_dist)
             if (this_cost < (cost)):
-                #print('current cost = ' + str(this_cost) + ', the max is ' + str(cost))
+                # print('current cost = ' + str(this_cost) + ', the max is ' + str(cost))
                 if debug:
                     print(('accepting rotate at theta  = ' + str(rotate_angle)))
                 cost = this_cost
@@ -478,18 +493,18 @@ def align_payload_to_multi_site(payload, surface_coord_list, cand_list, bind_dis
 ##################################
 
 
-def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, payload, cand_list, surface_coord_list, bind_dist, duplicate=False, control_angle=False, align_axis=False,align_ind=False, debug=False):
-     #   This function does final lowering, rotate and merge of previously aligned molecule with surface
-     #   Precede all calls to this funciton with allign_payload_to_Site to avoid strange behaviour
-     # INPUT
-     #   - super_cell: mol3D class that contains the super cell
-     #   - payload: mol3D class that contains that target molecule
-     #   - payload_ind: int, index of atom in payload that will bind to the surface
-     #   - align_coord: list of float, coordinates of the target surface site
-     #   - bind_dist: float, binding distance in A
-     #   - duplicate: logical, create a negative-z reflection as well?
-     # OUPUT
-     #   - combined_cel: mol3D class, loaded cell
+def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, payload, cand_list, surface_coord_list, bind_dist, duplicate=False, control_angle=False, align_axis=False, align_ind=False, debug=False):
+    #   This function does final lowering, rotate and merge of previously aligned molecule with surface
+    #   Precede all calls to this funciton with allign_payload_to_Site to avoid strange behaviour
+    # INPUT
+    #   - super_cell: mol3D class that contains the super cell
+    #   - payload: mol3D class that contains that target molecule
+    #   - payload_ind: int, index of atom in payload that will bind to the surface
+    #   - align_coord: list of float, coordinates of the target surface site
+    #   - bind_dist: float, binding distance in A
+    #   - duplicate: logical, create a negative-z reflection as well?
+    # OUPUT
+    #   - combined_cel: mol3D class, loaded cell
     combined_cell = mol3D()
     combined_cell.copymol3D(super_cell)
     new_payload = mol3D()
@@ -536,7 +551,6 @@ def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, paylo
         print(('\n\n Target distance was  ' + str(bind_dist) +
                ', achieved ' + str(distances_list)))
 
-    
     print('starting align rotation')
     for rotate_angle in range(0, 360):
         this_payload = mol3D()
@@ -546,8 +560,8 @@ def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, paylo
         this_cost = multialign_objective_function(
             this_payload, surface_coord_list, cand_list, bind_dist)
         if (this_cost < (cost)):
-                cost = this_cost
-                final_payload = this_payload
+            cost = this_cost
+            final_payload = this_payload
     if debug:
         print(('cost after rotation =' + str(cost)))
     distances_list = []
@@ -639,7 +653,7 @@ def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, paylo
         print((' Target distance was  ' + str(bind_dist) +
                ', achieved ' + str(distances_list)))
     min_dist = final_payload.mindist(combined_cell)
-   # now, rotate to maximize spacing, based on mask length
+    # now, rotate to maximize spacing, based on mask length
     rotate_on = False
     if len(cand_list) == 1:
         rotate_on = True
@@ -669,40 +683,36 @@ def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, paylo
                     print(('accepting rotate at theta  = ' + str(rotate_angle)))
                 min_dist = this_dist
                 final_payload = this_payload
-                
-                
-                
 
     if control_angle:
-            
-            print('inner control angle loop')
-            if not len(cand_list) == 1:
-                print('Warning! Using control angle with more than one payload,  reference will only use the FIRST payload reference ')
+        print('inner control angle loop')
+        if not len(cand_list) == 1:
+            print('Warning! Using control angle with more than one payload,  reference will only use the FIRST payload reference ')
 
-                print(('begining controlled rotation, targeting angle ' +
-                       str(control_angle) + ' to  line ' + str(align_axis)))
-                print(('aligning payload  index ' +
-                       str(cand_list[0]) + ' and indicies ' + str(align_ind-1) + ' with slab axes '))
-                this_payload = mol3D()
-                this_payload.copymol3D(final_payload)
-                
-                if debug:
-                    debug_cell = mol3D()
-                    debug_cell.copymol3D(combined_cell)
-                    debug_cell.combine(this_payload)
-                    this_payload.writexyz('aligned-payload-before-angle-control.xyz')
-                    debug_cell.writexyz('cell-before-angle-control.xyz')
+            print(('begining controlled rotation, targeting angle ' +
+                   str(control_angle) + ' to  line ' + str(align_axis)))
+            print(('aligning payload  index ' +
+                   str(cand_list[0]) + ' and indicies ' + str(align_ind-1) + ' with slab axes '))
+            this_payload = mol3D()
+            this_payload.copymol3D(final_payload)
+
+            if debug:
+                debug_cell = mol3D()
+                debug_cell.copymol3D(combined_cell)
+                debug_cell.combine(this_payload)
+                this_payload.writexyz('aligned-payload-before-angle-control.xyz')
+                debug_cell.writexyz('cell-before-angle-control.xyz')
+
+            this_payload = axes_angle_align(
+                this_payload, cand_list[0], align_ind-1, align_axis, control_angle)
+            if debug:
+                debug_cell = mol3D()
+                debug_cell.copymol3D(combined_cell)
+                debug_cell.combine(this_payload)
+                this_payload.writexyz('aligned-payload-after-angle-control.xyz')
+                debug_cell.writexyz('cell-before-after-control.xyz')
+            final_payload = this_payload
 
-                this_payload = axes_angle_align(
-                    this_payload, cand_list[0], align_ind-1, align_axis, control_angle)
-                if debug:
-                    debug_cell = mol3D()
-                    debug_cell.copymol3D(combined_cell)
-                    debug_cell.combine(this_payload)
-                    this_payload.writexyz('aligned-payload-after-angle-control.xyz')
-                    debug_cell.writexyz('cell-before-after-control.xyz')
-                final_payload = this_payload
-                
     if len(cand_list) > 1:
         # now, distort molecule based on FF to optimize bond length
         print('\n begining distortion ')
@@ -717,7 +727,6 @@ def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, paylo
             trans_vec_list.append(normalize_vector(vecdiff(v2, v1)))
             distances_list.append(distance(v1, v2) - bind_dist)
         ens = []
-        cutoff = 5.0  # kcal/mol
         distorted_payload = mol3D()
         distorted_payload.copymol3D(final_payload)
         for ii in range(0, nsteps+1):
@@ -739,7 +748,7 @@ def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, paylo
                 v1 = (surface_coord_list[indices[0]])
                 v2 = distorted_payload.getAtom(int(indices[1])).coords()
                 distances_list.append((distance(v1, v2) - bind_dist))
-            #print(str((abs(ens[-1] - ens[0]) < 5.0)) + str((this_cost < cost)) + str((this_dist >= (min_dist - 0.1))))
+            # print(str((abs(ens[-1] - ens[0]) < 5.0)) + str((this_cost < cost)) + str((this_dist >= (min_dist - 0.1))))
 
             if (abs(ens[-1] - ens[0]) < 5.0) and (this_cost < cost) and (this_dist >= (min_dist - 0.1)):
                 final_payload = distorted_payload
@@ -747,8 +756,7 @@ def combine_multi_aligned_payload_with_cell(super_cell, super_cell_vector, paylo
                 min_dist = this_dist
                 if debug:
                     print('accepting distort')
-                
-            
+
     distances_list = []
     for indices in enumerate(cand_list):
         v1 = (surface_coord_list[indices[0]])
@@ -795,7 +803,7 @@ def molecule_placement_supervisor(super_cell, super_cell_vector, target_molecule
         align_axis = False
     if control_angle and not align_ind:
         print('align_ind not found, even though control_angle is on. Disabling controlled rotation')
-        control_angle = false
+        control_angle = False
     if (method == 'alignpair') and not (surface_atom_type or surface_atom_ind):
         print('Must provide surface binding atom type to use alignpair')
         print(' using centered placemented instead')
@@ -920,7 +928,7 @@ def molecule_placement_supervisor(super_cell, super_cell_vector, target_molecule
             if debug:
                 print(('cand _ind = ' + str(cand_ind)))
             cand_list = [cand_ind]
-            #[(int(i)-1) for i in cand_ind]
+            # [(int(i)-1) for i in cand_ind]
         else:
             cand_ind = target_atom_type
             print('loading from TAT')
@@ -933,11 +941,10 @@ def molecule_placement_supervisor(super_cell, super_cell_vector, target_molecule
             payload, sites_list, cand_list, align_dist, debug)  # align
         if debug:
             payload.writexyz('aligned-payload-before-angle-control.xyz')
-        
-                
+
         if debug:
             print(('payload cysm ' + str(payload.centersym())))
-            
+
         #######################################
         temp_pay2 = mol3D()
         temp_pay2.copymol3D(payload)
@@ -947,7 +954,8 @@ def molecule_placement_supervisor(super_cell, super_cell_vector, target_molecule
             debug_cell.writexyz('db2.xyz')
         # lower payload to distance, rotate to avoid conflicr
         loaded_cell = combine_multi_aligned_payload_with_cell(
-            loaded_cell, super_cell_vector, payload, cand_list, sites_list, align_dist, duplicate, control_angle, align_axis,align_ind, debug)
+            loaded_cell, super_cell_vector, payload, cand_list, sites_list,
+            align_dist, duplicate, control_angle, align_axis, align_ind, debug)
 
         ########################
         temp_pay3 = mol3D()
@@ -960,13 +968,11 @@ def molecule_placement_supervisor(super_cell, super_cell_vector, target_molecule
         # print("\n")
     # run tests
     overlap_flag = loaded_cell.sanitycheck(0)
-    min_dist = loaded_cell.mindistmol()
     if (number_of_placements > 1):
         print(('preparing ' + str(number_of_placements) + ' placements '))
         effectvie_coverage = float(number_of_placements)/float(max_sites)
         print(('giving effectvie coverage of ' + str(effectvie_coverage) + '\n'))
     print(('Is there overalp? ' + str(overlap_flag)))
-    min_intercell_d = closest_torus_point(payload, extents)
 
     return loaded_cell
 
@@ -1013,15 +1019,27 @@ def staggered2_align_coord(super_cell):
 
 
 def axes_angle_align(payload, cand_ind, align_ind, align_target, angle):
-     #   This function rotates a given payload molecule such that the X-Y projection of
-     #   the cord joining the two atoms in cand_ind and  align_ind is aligned with the vector given in align_target
-     # INPUT
-     #   - payload: mol3D class that contains that target molecule
-     #   - cand_ind: int, index of atom in payload that is used as reference
-     #   - align_ind: int, index of atom in payload that define the cord to align
-     #   - align_target: list of 3 float, vector on the cell surface to align. Normally z=0
-     # OUPUT
-     #   - new_payload: mol3D class, rotation of payload
+    """This function rotates a given payload molecule such that the X-Y
+    projection of the cord joining the two atoms in cand_ind and align_ind
+    is aligned with the vector given in align_target.
+
+    Parameters
+    ----------
+    payload : mol3D
+        mol3D class that contains that target molecule
+    cand_ind : int
+        index of atom in payload that is used as reference
+    align_ind : int
+        index of atom in payload that define the cord to align
+    align_target : list of 3 float
+        vector on the cell surface to align. Normally z=0
+    angle : float
+        rotation angle
+    Returns
+    -------
+    new_payload: mol3D
+        mol3D class, rotation of payload.
+    """
     new_payload = mol3D()
     new_payload.copymol3D(payload)
     align_chord = vecdiff(new_payload.getAtom(
@@ -1069,7 +1087,7 @@ def slab_module_supervisor(args, rootdir):
     # optional_input
     miller_index = False
     # Required Input: placement
-    #target_molecule =  False
+    # target_molecule =  False
     align_distance_method = False
     # options are "physisorption","chemisorption","custom"
     align_dist = False  # use in conjunction with "custom" above
@@ -1082,15 +1100,12 @@ def slab_module_supervisor(args, rootdir):
     num_surface_atoms = 1
     num_placements = 1
     coverage = False
-    multi_placement_centering = 0.95
+    # multi_placement_centering = 0.95
     # for surface rotation:
     control_angle = False
     angle_control_partner = False
     angle_surface_axis = False
 
-    # for non-orthogonal unit cells
-    ortho_cell = False
-
     # duplication
     duplicate = False
 
@@ -1115,7 +1130,7 @@ def slab_module_supervisor(args, rootdir):
     ###### Now attempt input ####
     import_success = True
     emsg = list()
-    multi_placement_centering_overide = False
+    # multi_placement_centering_overide = False
     miller_flag = False
     if (args.slab_gen):  # 0
         slab_gen = True
@@ -1130,10 +1145,10 @@ def slab_module_supervisor(args, rootdir):
             elif (ext == '.mol'):
                 unit_cell.OBmol = unit_cell.getOBmol(args.unit_cell)
                 unit_cell.convert2mol3D()
-        except:
+        except FileNotFoundError:
             emsg.append('Unable to import unit cell at  ' +
                         str(args.unit_cell))
-            import_success == False
+            import_success = False
     if (args.cell_vector):  # 2
         cell_vector = args.cell_vector
     if (args.cif_path):  # 3
@@ -1153,7 +1168,7 @@ def slab_module_supervisor(args, rootdir):
         expose_type = args.expose_type
     if (args.shave_extra_layers):  # 10
         shave_extra_layers = args.shave_extra_layers
-     # ## parse placement options
+    # parse placement options
     if (args.place_on_slab):  # 0
         place_on_slab = True
     if (args.target_molecule):  # 1
@@ -1168,7 +1183,7 @@ def slab_module_supervisor(args, rootdir):
                 target_molecule.OBmol = unit_cell.getOBmol(
                     args.target_molecule)
                 target_molecule.convert2mol3D()
-        except:
+        except FileNotFoundError:
             emsg.append('Unable to import target at  ' +
                         str(args.target_molecule))
             import_success = False
@@ -1191,9 +1206,9 @@ def slab_module_supervisor(args, rootdir):
         num_placements = args.num_placements
     if (args.coverage):  # 10
         coverage = args.coverage
-    if (args.multi_placement_centering):  # 12
-        multi_placement_centering = args.multi_placement_centering
-        multi_placement_centering_overide = True
+    # if (args.multi_placement_centering):  # 12
+    #     multi_placement_centering = args.multi_placement_centering
+    #     multi_placement_centering_overide = True
     if (args.control_angle):  # 13
         control_angle = args.control_angle
     if (args.angle_control_partner):  # 14
@@ -1216,8 +1231,8 @@ def slab_module_supervisor(args, rootdir):
     if not import_success:
         print(emsg)
         return emsg
-    if num_placements > 1 and not multi_placement_centering_overide:
-        multi_placement_centering = 1  # reccomended for multiple placments
+    # if num_placements > 1 and not multi_placement_centering_overide:
+    #     multi_placement_centering = 1  # reccomended for multiple placments
     if not slab_gen and not place_on_slab:
         emsg.append(
             'Slab builder module not enabled, placement mode not enabled - no action taken ')
@@ -1285,14 +1300,13 @@ def slab_module_supervisor(args, rootdir):
             if debug:
                 print('cell vector from cif is')
                 print(cell_vector)
-      #  except:
-      #      emsg.append('unable to import cif at ' + str(cif_path))
-      #      print(emsg)
-      #      return emsg
+            # except:
+            #     emsg.append('unable to import cif at ' + str(cif_path))
+            #     print(emsg)
+            #     return emsg
 
         # testing
         unit_cell.writexyz(rootdir + 'slab/before_COB.xyz')
-        old_basis = cell_vector
         print('loaded')
 
         if miller_flag:
@@ -1382,7 +1396,7 @@ def slab_module_supervisor(args, rootdir):
         if miller_index:
             print(('rotating angle ' + str(angle) + ' around ' + str(u)))
             super_cell = rotate_around_axis(super_cell, [0, 0, 0], u, angle)
-            #decoy = rotate_around_axis(decoy,[0,0,0],u,angle)##
+            # decoy = rotate_around_axis(decoy,[0,0,0],u,angle)##
             cell_vector = [PointRotateAxis(u, [0, 0, 0], list(
                 i), numpy.pi*angle/(180)) for i in cell_vector]
             ext_duplication_vector = [PointRotateAxis(u, [0, 0, 0], list(
@@ -1391,8 +1405,6 @@ def slab_module_supervisor(args, rootdir):
             cell_vector = threshold_basis(cell_vector, 1E-6)
             ext_duplication_vector = threshold_basis(
                 ext_duplication_vector, 1E-6)
-            u_keep = 0 + u
-            angle_keep = 0+angle
         #############################################################
 
         if debug:
@@ -1458,7 +1470,6 @@ def slab_module_supervisor(args, rootdir):
         if debug:
             super_cell.writexyz(rootdir + 'slab/after_size_control.xyz')
         # measure and recored slab vectors
-        super_cell_dim = find_extents(super_cell)
         super_cell_vector = copy.copy(ext_duplication_vector)
 
         # check if passivation needed
@@ -1485,7 +1496,7 @@ def slab_module_supervisor(args, rootdir):
         #    super_cell_vector[0] = [-1*i for i in super_cell_vector[0]]
         point_coefficients = [get_basis_coefficients(
             at.coords(), super_cell_vector) for at in super_cell.getAtoms()]
-        #print('coords in final slab:' )
+        # print('coords in final slab:' )
         # print(point_coefficients)
         point_coefficients = threshold_basis(point_coefficients, 1E-6)
         # for i in range(0,len(point_coefficients)):
@@ -1500,11 +1511,11 @@ def slab_module_supervisor(args, rootdir):
         # for j,points in enumerate(point_coefficients):
         # if min(new_coords[i])<0:
         # try shift one cv in each direction:
-        #potential_new_point = []
+        # potential_new_point = []
 
         for i, coords in enumerate(new_coords):
             super_cell.getAtom(i).setcoords(coords)
-        #point_coefficients = [get_basis_coefficients(at.coords(),super_cell_vector) for at in super_cell.getAtoms()]
+        # point_coefficients = [get_basis_coefficients(at.coords(),super_cell_vector) for at in super_cell.getAtoms()]
         print('coords in final slab:')
         print(point_coefficients)
         ######
@@ -1549,8 +1560,7 @@ def slab_module_supervisor(args, rootdir):
             print(angle_surface_axis)
             angle_surface_axis.append(0)
             print(angle_surface_axis)
-            
-            
+
         print(('object_align ' + str(object_align)))
         loaded_cell = molecule_placement_supervisor(super_cell, super_cell_vector, target_molecule,
                                                     align_method, object_align, align_dist, surface_atom_type,
