@@ -1,51 +1,63 @@
 # @file generator.py
 #  Main script that coordinates all parts of the program.
 #
-#  Written by Tim Ioannidis and JP Janet for HJK Group
+#  Written by Kulik Group
 #
-#  Dpt of Chemical Engineering, MIT
+#  Department of Chemical Engineering, MIT
 
-#!/usr/bin/env python
-
-'''
-    Copyright 2017 Kulik Lab @ MIT
-
-    This file is part of molSimplify.
-    molSimplify is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published
-    by the Free Software Foundation, either version 3 of the License,
-    or (at your option) any later version.
-
-    molSimplify is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-    See the GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with molSimplify. If not, see http://www.gnu.org/licenses/.
-'''
-
-import sys
 import os
-import random
-import shutil
-import inspect
+import sys
+import glob
 import argparse
-import openbabel
-from molSimplify.Scripts.rungen import *
-from molSimplify.Scripts.molSimplify_io import *
-from molSimplify.Scripts.inparse import *
-from molSimplify.Scripts.dbinteract import *
-from molSimplify.Scripts.postproc import *
-from molSimplify.Scripts.cellbuilder import*
-from molSimplify.Scripts.chains import*
-from molSimplify.Scripts.findcorrelations import*
-from molSimplify.Scripts.addtodb import*
-from molSimplify.Classes.globalvars import *
-from molSimplify.Classes.mol3D import mol3D
-from molSimplify.Classes.atom3D import atom3D
-from math import sqrt
-from math import floor
+import copy
+from molSimplify.Classes.globalvars import (globalvars)
+from molSimplify.Scripts.addtodb import addtoldb
+from molSimplify.Scripts.io import loadcdxml
+from molSimplify.Scripts.cellbuilder import (slab_module_supervisor)
+from molSimplify.Scripts.chains import (chain_builder_supervisor)
+from molSimplify.Scripts.dbinteract import (dbsearch)
+from molSimplify.Scripts.findcorrelations import (analysis_supervisor)
+from molSimplify.Scripts.inparse import (checkinput,
+                                         cleaninput,
+                                         parseall,
+                                         parseinputfile)
+from molSimplify.Scripts.postproc import (postproc)
+from molSimplify.Scripts.rungen import (constrgen,
+                                        multigenruns,
+                                        draw_supervisor)
+
+
+def startgen_pythonic(input_dict={'-core': 'fe', '-lig': 'cl,cl,cl,cl,cl,cl'},
+                      argv=['main.py', '-i', 'asdfasdfasdfasdf'],
+                      flag=True,
+                      gui=False):
+    """This is the main way to generate structures completely within Python.
+
+        Parameters
+        ----------
+            input_dict : dict
+                Argument list in the form of a dictionary.
+            argv : list
+                Default argument list used to "fool" startgen into accepting input_dict.
+            flag : bool, optional
+                Flag for printing information. Default is True.
+            gui : bool, optional
+                Flag for GUI. Default is False.
+
+        Returns
+        -------
+            strfiles : str
+                Folder containing the runs.
+            emsg : bool
+                Flag for error. If error, returns a string with error.
+            this_diag : rundiag 
+                Rundiag class instance that contains ANN attributes (this_diag.ANN_attributes) and a mol3D class instance (this_diag.mol).
+            
+    """
+    # from molSimplify.Scripts.generator import startgen_pythonic
+    inputfile_str = '\n'.join([k + ' ' + v for k, v in list(input_dict.items())])
+    strfiles, emsg, this_diag = startgen(argv, flag, gui, inputfile_str, write_files=False)
+    return (strfiles, emsg, this_diag)
 
 
 # Coordinates subroutines
@@ -53,11 +65,32 @@ from math import floor
 #  @param flag Flag for printing information
 #  @param gui Flag for GUI
 #  @return Error messages
-def startgen(argv, flag, gui):
+def startgen(argv, flag, gui, inputfile_str=None, write_files=True):
+    """Coordinates subroutines.
+
+        Parameters
+        ----------
+            argv : list
+                Argument list.
+            flag : bool
+                Flag for printing information.
+            gui : bool
+                Flag for GUI.
+            inputfile_str : str, optional
+                Optional input passed in as a string. Default is None.
+            write_files : bool, optional
+                Flag for whether or not files should be written. Should set to false for pythonic generation.
+
+        Returns
+        -------
+            emsg : bool
+                Flag for error. If error, returns a string with error.
+
+    """
     emsg = False
     # check for configuration file
-    homedir = os.path.expanduser("~")
-    #configfile = False if not glob.glob(homedir+'/.molSimplify') else True
+    # homedir = os.path.expanduser("~")
+    # configfile = False if not glob.glob(homedir+'/.molSimplify') else True
     # if not configfile:
     #    print "It looks like the configuration file '~/.molSimplify' does not exist!Please follow the next steps to configure the file."
     #    instdir = raw_input("Please select the full path of the top installation directory for the program: ")
@@ -74,7 +107,7 @@ def startgen(argv, flag, gui):
     ### end set-up configuration file ###
     ############ GLOBALS DEFINITION ############
     globs = globalvars()
-    #installdir = globs.installdir
+    # installdir = globs.installdir
     rundir = globs.rundir
     PROGRAM = globs.PROGRAM
     ###### END GLOBALS DEFINITION ##############
@@ -91,14 +124,14 @@ def startgen(argv, flag, gui):
     parser = argparse.ArgumentParser()
     args = parseall(parser)
     # check if input file exists
-    if not glob.glob(args.i):
+    if not glob.glob(args.i) and not inputfile_str:
         emsg = 'Input file '+args.i+' does not exist. Please specify a valid input file.\n'
         print(emsg)
         return emsg
     args.gui = gui  # add gui flag
     # parse input file
-    if args.i:
-        parseinputfile(args)
+    if args.i or inputfile_str:
+        parseinputfile(args, inputfile_str=inputfile_str)
     if args.cdxml:
         print('converting cdxml file into xyz')
         cdxml = args.cdxml[0]
@@ -132,7 +165,8 @@ def startgen(argv, flag, gui):
     # check for jobs directory
     rundir = args.rundir+'/' if (args.rundir) else rundir
     if not os.path.isdir(rundir):
-        os.mkdir(rundir)
+        if write_files:
+            os.mkdir(rundir)
     ################### START MAIN ####################
     args0 = copy.deepcopy(args)  # save initial arguments
     # add gui flag
@@ -171,8 +205,8 @@ def startgen(argv, flag, gui):
                 print(emsg)
                 del args
                 return emsg
-    # elif args.drawmode:
-    #    emsg = draw_supervisor(args,rundir)
+    elif args.drawmode:
+        emsg = draw_supervisor(args, rundir)
     # slab/place on slab?
     elif (args.slab_gen or args.place_on_slab):
         emsg = slab_module_supervisor(args, rundir)
@@ -206,7 +240,7 @@ def startgen(argv, flag, gui):
             print('building an equilibrium complex')
         for cc in corests:
             args.core = cc
-            emsg = multigenruns(rundir, args, globs)
+            emsg = multigenruns(rundir, args, globs, write_files=write_files)
             if emsg:
                 print(emsg)
                 del args
