@@ -5,17 +5,20 @@
 #
 #  Dpt of Chemical Engineering, MIT
 
-import glob
+import argparse
 import os
 import re
-import argparse
-import sys
-import ast
-import json
+
 import yaml
-from molSimplify.Scripts.molSimplify_io import *
-from molSimplify.Classes.globalvars import *
-from pkg_resources import resource_filename, Requirement
+
+from molSimplify.Classes.globalvars import (defaultspins,
+                                            elementsbynum,
+                                            globalvars,
+                                            metals_conv,
+                                            romans,
+                                            mtlsdlist)
+from molSimplify.Scripts.io import (getbinds, getcores, getgeoms, getlicores,
+                                    getslicores, printgeoms, substr_load)
 
 
 # Checks input for correctness and uses defaults otherwise
@@ -44,7 +47,7 @@ def checkinput(args, calctype="base"):
                     print(('WARNING: No oxidation state specified. Defaulting to ' +
                           globs.defaultoxstate[args.core[0].lower()]))
                     args.oxstate = globs.defaultoxstate[args.core[0].lower()]
-                except:
+                except KeyError:
                     print('WARNING: No oxidation state specified. Defaulting to 2')
                     args.oxstate = '2'
             # check spin state (doesn't work for custom cores)
@@ -71,7 +74,7 @@ def checkinput(args, calctype="base"):
                         'WARNING: No spin multiplicity specified. Defaulting to singlet (1)')
                 args.spin = defaultspinstate
 
-             # check coordination number and geometry from ligands if given
+            # check coordination number and geometry from ligands if given
             if (not args.coord) and (not args.geometry) and args.lig:
                 if not args.gui:
                     # calculate occurrences, denticities etc for all ligands
@@ -127,7 +130,7 @@ def checkinput(args, calctype="base"):
             # default ligand if none given
             if not args.lig and not args.rgen:
                 if args.gui:
-                    from Classes.mWidgets import mQDialogWarn
+                    from molSimplify.Classes.mWidgets import mQDialogWarn
                     qqb = mQDialogWarn('Warning', 'You specified no ligands.')
                     qqb.setParent(args.gui.wmain)
                 else:
@@ -149,7 +152,7 @@ def checkinput(args, calctype="base"):
                 else:
                     try:
                         args.coord = coords[geomnames.index(args.geometry)]
-                    except:
+                    except ValueError:
                         args.coord = coords[geomshorts.index(args.geometry)]
                     print((
                         'WARNING: No coordination number specified. Defaulting to '+str(args.coord)))
@@ -162,7 +165,7 @@ def checkinput(args, calctype="base"):
                     args.ligocc.append(0)
     elif calctype == "tsgen":
         # load substrate for reference
-        print(args.substrate[0],0, args.subcatoms)
+        print(args.substrate[0], 0, args.subcatoms)
         sub, subcatoms, emsg = substr_load(
             args.substrate[0], 0, args.subcatoms)
         # check core
@@ -179,7 +182,7 @@ def checkinput(args, calctype="base"):
                     print(('WARNING: No oxidation state specified. Defaulting to ' +
                           globs.defaultoxstate[args.core[0].lower()]))
                     args.oxstate = globs.defaultoxstate[args.core[0].lower()]
-                except:
+                except KeyError:
                     print('WARNING: No oxidation state specified. Defaulting to 2')
                     args.oxstate = '2'
             # check spin state (doesn't work for custom cores)
@@ -208,7 +211,7 @@ def checkinput(args, calctype="base"):
             # check ligands
             if not args.lig and not args.rgen:
                 if args.gui:
-                    from Classes.mWidgets import mQDialogWarn
+                    from molSimplify.Classes.mWidgets import mQDialogWarn
                     qqb = mQDialogWarn('Warning', 'You specified no ligands.')
                     qqb.setParent(args.gui.wmain)
                 else:
@@ -294,7 +297,7 @@ def checkinput(args, calctype="base"):
                 else:
                     try:
                         args.coord = coords[geomnames.index(args.geometry)]
-                    except:
+                    except ValueError:
                         args.coord = coords[geomshorts.index(args.geometry)]
                     print((
                         'WARNING: No coordination number specified. Defaulting to '+str(args.coord)))
@@ -320,7 +323,7 @@ def checkinput(args, calctype="base"):
             # check mlig connecting point if the ligand has more than one atom
             if args.mlig and not args.mligcatoms:
                 sub, subcatoms, emsg = substr_load(args.mlig[0], 0, subcatoms)
-                if sub.natoms is 1:
+                if sub.natoms == 1:
                     args.mligcatoms = [0]
                 else:
                     print('WARNING: A ligand in the metal complex is specified to connect with the substrate for TS generation without the specification of a connection point in the ligand. Defaulting to atom index 0.')
@@ -377,7 +380,6 @@ def is_number(s):
 
 
 def cleaninput(args):
-    globs = globalvars()
     # check ligands
     if args.lig:
         ls = []
@@ -468,20 +470,17 @@ def cleaninput(args):
     if not args.keepHs:
         args.keepHs = [keepHs_default]
     if args.keepHs and args.lig:
-        while len(args.keepHs) < len(args.lig):
+        while len(args.keepHs) < len(args.lig):  # user should specify as many booleans for keepHs as there are kinds of ligands if she wants to avoid default assignment
             args.keepHs.append(keepHs_default)
         for i, s in enumerate(args.keepHs):
             if args.keepHs[i].lower() != 'auto':
                 args.keepHs[i] = checkTrue(s)
     # parse FF settings:
     # if no FF opt is requested, turn off
-    if args.ffoption[0].lower() == ('n' or 'no'):
+    if args.ffoption[0].lower() in ['n', 'no']:
         args.ff = False
     # if FF opt is desired, parse FF choice
     else:
-        b = False
-        a = False
-        e = False
         opts = args.ffoption
         if 'ba' in opts[0].lower():
             args.ffoption = 'ba'
@@ -519,7 +518,7 @@ def parseCLI(args):
 #  @param args Namespace of arguments
 
 
-def parseinputfile(args):
+def parseinputfile(args, inputfile_str=None):
     # arguments that don't match with  inparse name and
     # are not automatically initialized go here:
     args.skipANN = False
@@ -533,8 +532,12 @@ def parseinputfile(args):
 
     # (we should remove these where posible)
     # THIS NEEDS CLEANING UP TO MINIMIZE DUPLICATION WITH parsecommandline
+    if inputfile_str:
+        inputfile_lines = inputfile_str.split('\n')
+    else:
+        inputfile_lines = open(args.i)
 
-    for line in open(args.i):
+    for line in inputfile_lines:
         # For arguments that cannot accept smiles as args, split possible comments
         if '-lig' not in line and '-core' not in line and '-bind' not in line and '-dbsmarts' not in line:
             line = line.split('#')[0]  # remove comments
@@ -543,15 +546,15 @@ def parseinputfile(args):
         line = line.replace('\n', '')
         if not li.startswith("#") and len(li) > 0:  # ignore comments/empty lines
             # split arguments on whitespace, commas (this breaks smarts)
-            l = [_f for _f in re.split(' |\t|,|&', li) if _f]
+            l = [_f for _f in re.split(' |\t|,|&', li) if _f]  # noqa: E741
             # parse general arguments
             if (l[0] == '-core' and len(l[1:]) > 0):
                 args.core = [ll for ll in l[1:]]
             if (l[0] == '-ccatoms' and len(l[1:]) > 0):
                 args.ccatoms = []
-                l = line.split('ccatoms', 1)[1]
-                l = l.strip(' ')
-                l = l.split(',')
+                l = line.split('ccatoms', 1)[1]  # noqa: E741
+                l = l.strip(' ')  # noqa: E741
+                l = l.split(',')  # noqa: E741
                 args.ccatoms = [int(ll)-1 for ll in l]
             if (l[0] == '-rundir'):
                 set_rundir = True
@@ -578,11 +581,11 @@ def parseinputfile(args):
                     args.jobdirblank = True
             ### parse structure generation arguments ###
             if (l[0] == '-bind' and len(l[1:]) > 0):
-                l = [_f for _f in re.split(' |,|\t', line) if _f]
+                l = [_f for _f in re.split(' |,|\t', line) if _f]  # noqa: E741
                 # discard comments
                 for ibind, lbind in enumerate(l):
                     if lbind == '#':
-                        l = l[:ibind]
+                        l = l[:ibind]  # noqa: E741
                         break
                 args.bind = l[1]
             if (l[0] == '-nbind' and len(l[1:]) > 0):
@@ -609,6 +612,8 @@ def parseinputfile(args):
                 args.coord = l[1]
             if (l[0] == '-geometry' and len(l[1:]) > 0):
                 args.geometry = l[1].lower()
+            if (l[0] == '-geo' and len(l[1:]) > 0):
+                args.geometry = l[1].lower()
             # parse ligands
             if (l[0] == '-lig') and len(l[1:]):
                 args.lig = l[1:]
@@ -652,7 +657,9 @@ def parseinputfile(args):
                 args.ff = l[1].lower()
             if (l[0] == '-ffoption' and len(l[1:]) > 0):
                 args.ffoption = l[1:]
-                #print('setting ffoption ' + str(args.ffoption))
+                # print('setting ffoption ' + str(args.ffoption))
+            if (l[0] == '-ff_final_opt' and len(l[1:]) > 0):
+                args.ff_final_opt = l[1].lower()
             if (l[0] == '-place' and len(l[1:]) > 0):
                 args.place = l[1]
             if (l[0] == '-sminame' and len(l[1:]) > 0):
@@ -662,9 +669,9 @@ def parseinputfile(args):
                     args.sminame = l[1:]
             if '-smicat' in line:
                 args.smicat = []
-                l = line.split('smicat', 1)[1]
-                l = l.replace(' ', '')
-                l = l.split('],[')
+                l = line.split('smicat', 1)[1]  # noqa: E741
+                l = l.replace(' ', '')  # noqa: E741
+                l = l.split('],[')  # noqa: E741
                 for smicats in l:
                     smicats = smicats.strip('[]')
                     smicats = smicats.split(',')
@@ -675,7 +682,7 @@ def parseinputfile(args):
                                 lloc.append(int(ll)-1)
                             else:
                                 lloc.append(ll.lower())
-                        except:
+                        except ValueError:
                             print(('ERROR: smicat processing failed at ' + str(ll)))
                             print(
                                 'Please use integers or  "pi" and divide by smiles ligand using [],[]')
@@ -685,14 +692,14 @@ def parseinputfile(args):
             if (l[0] == '-nconfs' and len(l[1:]) > 0):
                 args.nconfs = l[1]
             # if (l[0]=='-maxconfs' and len(l[1:]) > 0):
-                #args.maxconfs = l[1]
+                # args.maxconfs = l[1]
             if (l[0] == '-scoreconfs'):
                 args.scoreconfs = True
             if '-pangles' in line:
                 args.pangles = []
-                l = [_f for _f in line.split('pangles', 1)[1] if _f]
-                l = l.replace(' ', '')
-                l = re.split(',|\t|&|\n', l)
+                l = [_f for _f in line.split('pangles', 1)[1] if _f]  # noqa: E741
+                l = l.replace(' ', '')  # noqa: E741
+                l = re.split(',|\t|&|\n', l)  # noqa: E741
                 for ll in l:
                     args.pangles.append(
                         ll) if ll != '' else args.pangles.append(False)
@@ -714,7 +721,7 @@ def parseinputfile(args):
                 local_list = list()
                 if not isinstance(list_to_parse, str):
                     for decor in list_to_parse:
-                        #print('correcting string')
+                        # print('correcting string')
                         decor = str(decor).strip().strip('[]').split(',')
                         # print(decor)
                         local_list = local_list + [str(i) for i in decor]
@@ -736,6 +743,10 @@ def parseinputfile(args):
                 args.charge = l[1:]
             if (l[0] == '-spin' and len(l[1:]) > 0):
                 args.spin = l[1:]
+            if (l[0] == '-spinmultiplicity' and len(l[1:]) > 0):
+                args.spin = l[1:]
+            if (l[0] == '-multiplicity' and len(l[1:]) > 0):
+                args.spin = l[1:]
             if (l[0] == '-runtyp' and len(l[1:]) > 0):
                 args.runtyp = l[1]
             if (l[0] == '-method' and len(l[1:]) > 0):
@@ -861,6 +872,10 @@ def parseinputfile(args):
                 args.dbmw = l[1]
             if (l[0] == '-dbnsearch'):
                 args.dbnsearch = l[1]
+            if (l[0] == '-drawmode'):
+                args.drawmode = True
+            else:
+                args.drawmode = False
             if (l[0] == '-dballowedels'):
                 args.dballowedels = l[1:]
             if (l[0] == '-dbfname'):
@@ -874,11 +889,11 @@ def parseinputfile(args):
                 args.dbvdent = l[1]
             if (l[0] == '-dbvconns'):
                 ll = [x for x in l[1:]]
-                #ll = filter(None,re.split(' |,|\t',l[1]))
+                # ll = filter(None,re.split(' |,|\t',l[1]))
                 args.dbvconns = ll
             if (l[0] == '-dbvhyb'):
                 ll = [x for x in l[1:]]
-                #ll = filter(None,re.split(' |,|\t',l[1]))
+                # ll = filter(None,re.split(' |,|\t',l[1]))
                 args.dbvhyb = ll
             if (l[0] == '-dbvlinks'):
                 args.dbvlinks = l[1]
@@ -960,7 +975,7 @@ def parseinputfile(args):
             if (l[0] == '-freeze'):  # 7
                 try:
                     args.freeze = int(l[1].strip('(){}<>[],.'))
-                except:
+                except ValueError:
                     args.freeze = True
             if (l[0] == '-debug'):  # 8
                 args.debug = True
@@ -1047,14 +1062,13 @@ def parseinputfile(args):
             if (l[0] == '-max_descriptors'):
                 args.max_descriptors = [str(i) for i in l[1:]]
     if not set_rundir:
-        args.rundir = os.path.join(os.path.abspath('.'),'Runs')
+        args.rundir = os.path.join(os.path.abspath('.'), 'Runs')
 # Parses command line arguments and prints help information
 #  @param parser Parser object
 #  @return Namespace of arguments
 
 
 def parseall(parser):
-    globs = globalvars()
     parser.add_argument("-i", help="input file")
     # hidden (non-user) arguments for GUI
     parser.add_argument("-rprompt", help=argparse.SUPPRESS,
@@ -1095,15 +1109,32 @@ def parseinputs_basic(*p):
     parser.add_argument(
         "-coord", help="coordination such as 4,5,6", action="store_true")
     parser.add_argument("-geometry", help="geometry", action="store_true")
+    parser.add_argument("-geo", help="geometry", action="store_true")
     parser.add_argument("-lig", help="ligands to be included in complex")
     parser.add_argument(
         "-ligocc", help="number of corresponding ligands", action="store_true")  # e.g. 1,2,1
-    parser.add_argument(
-        "-spin", help="Spin multiplicity (e.g., 1 for singlet)")
+    parser.add_argument("-spin", help="Spin multiplicity (e.g., 1 for singlet)")
+    parser.add_argument("-spinmultiplicity", help="Spin multiplicity (e.g., 1 for singlet)")
+    parser.add_argument("-multiplicity", help="Spin multiplicity (e.g., 1 for singlet)")
     # specified in cleaninput
     parser.add_argument(
         "-keepHs", help="force keep hydrogens, default auto for each ligand")
     parser.add_argument("-skipANN", help="skip attempting ANN predictions")
+    parser.add_argument(
+        "-rundir", help="directory for jobs, default ~/Runs", action="store_true")
+    parser.add_argument(
+        "-smicat", help="connecting atoms corresponding to smiles. Indexing starts at 1 which is the default value as well. Use [] for multiple SMILES ligands, e.g. [1],[2]", action="store_true")
+    parser.add_argument(
+        "-ligloc", help="force location of ligands in the structure generation (default False)", default=False)
+    parser.add_argument(
+        "-ff", help="select force field for FF optimization. Available: (default) MMFF94, UFF, GAFF, Ghemical, XTB, GFNFF", default='uff')
+    parser.add_argument(
+        "-ffoption", help="select when to perform FF optimization. Options: B(Before),A(After), (default) BA, N(No)", default='BA')
+    parser.add_argument(
+        "-ff_final_opt", help="optionally select different force field for "
+        "final FF optimization after structure generation (defaults to option"
+        " used in -ff). Available: MMFF94, UFF, GAFF, Ghemical, XTB, GFNFF",
+        default=None)
     if len(p) == 1:  # only one input, printing help only
         args = parser.parse_args()
         return args
@@ -1119,27 +1150,17 @@ def parseinputs_basic(*p):
 def parseinputs_advanced(*p):
     parser = p[0]
     # advanced structure generation options
-    parser.add_argument(
-        "-rundir", help="directory for jobs, default ~/Runs", action="store_true")
-    parser.add_argument(
-        "-smicat", help="connecting atoms corresponding to smiles. Indexing starts at 1 which is the default value as well. Use [] for multiple SMILES ligands, e.g. [1],[2]", action="store_true")
     parser.add_argument(
         "-nconfs", help="Number of conformers to generate for multidentate smiles ligands. Default 1.", default='1')
     parser.add_argument(
         "-scoreconfs", help="Attempt to filter out identical conformers and rank them by rmsd to the desired template, default false", default=False)
-    #parser.add_argument("-maxconfs", help="Stop generation after maxconfs unique conformers or nconfs conformers have been generated, whichever comes first, default infinite", default=10000)
+    # parser.add_argument("-maxconfs", help="Stop generation after maxconfs unique conformers or nconfs conformers have been generated, whichever comes first, default infinite", default=10000)
     parser.add_argument(
         "-charge", help="Net complex charge. Recommended NOT to specify, by default this is calculated from the metal oxidation state and ligand charges.")
     parser.add_argument(
         "-calccharge", help="Automatically calculate net complex charge. By default this is ON.", default=True)
-    parser.add_argument(
-        "-ff", help="select force field for FF optimization. Available: (default) MMFF94, UFF, GAFF, Ghemical", default='uff')
-    parser.add_argument(
-        "-ffoption", help="select when to perform FF optimization. Options: B(Before),A(After), (default) BA, N(No)", default='BA')
     parser.add_argument(
         "-genall", help="Generate complex both with and without FF opt, default False", action="store_true")  # geometry
-    parser.add_argument(
-        "-ligloc", help="force location of ligands in the structure generation (default False)", default=False)
     parser.add_argument("-decoration_index", help="list of indicies on each ligand to decorate",
                         action="store_true")  # decoration indexes, one list per ligand
     parser.add_argument("-decoration", help="list of SMILES for each decoratation",
@@ -1592,11 +1613,13 @@ def parseinputs_naming(*p):
         parser.parse_args(namespace=args)
     return 0
 
+
 def deserialize_json(filein):
     with open(filein, "r") as fo:
         args_dict = yaml.safe_load(fo)
     return args_dict
 
+
 def args_parser_retrain():
     parser = argparse.ArgumentParser()
     parser.add_argument('-user')
@@ -1605,4 +1628,3 @@ def args_parser_retrain():
     parser.add_argument('-infile')
     args = parser.parse_args()
     return args
-
