@@ -5,15 +5,6 @@
 #
 #  Dpt of Chemical Engineering, MIT
 
-from .structgen import *
-from molSimplify.Scripts.molSimplify_io import *
-import argparse
-import sys
-import os
-import shutil
-import itertools
-import random
-
 # Generates name for complex given core and ligands
 #  @param core mol3D of core
 #  @param ligs List of ligand names
@@ -36,6 +27,6 @@ def name_complex(core, ligs, ligoc, args):
         spin = "0"
     name += "_ " + str(spin)
     for i, lig in enumerate(ligs):
-        names += '_' + str(lig[:3]) + '-' + str(ligoc[i])
-    names += "_"+str(spin)
+        name += '_' + str(lig[:3]) + '-' + str(ligoc[i])
+    name += "_"+str(spin)
     return name
