@@ -5,11 +5,9 @@
 #
 #  Dpt of Chemical Engineering, MIT
 
-import os
-import sys
-import subprocess
 import time
-from molSimplify.Classes.globalvars import *
+import os
+
 
 # Gets subset of string between two substrings
 #  @param s String to be split
@@ -175,7 +173,6 @@ def nbo_parser_restricted(s):
 
 def spinnbo(s, metal):
     sNBO = []
-    sLV = []
     # get molecular orbitals containing metal
     ss = s.split('NATURAL BOND ORBITAL')[1]
     ss2 = ss.split('DIRECTIONALITY')
