@@ -1,26 +1,35 @@
 # @file qcgen.py
 #  Generates quantum chemistry input files
 #
-#  Written by Tim Ioannidis and JP Janet for HJK Group
+#  Written by Kulik Group
 #
-#  Dpt of Chemical Engineering, MIT
+#  Department of Chemical Engineering, MIT
 
-from molSimplify.Classes.globalvars import *
-import glob
-import sys
-import os
 import shutil
-from molSimplify.Classes.mol3D import mol3D
-from molSimplify.Classes.atom3D import atom3D
-from molSimplify.Classes.globalvars import *
+import os
 
-# Generate multiple terachem runs if multiple methods requested
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @return List of job directories
+from molSimplify.Classes.globalvars import (globalvars,
+                                            romans)
+from molSimplify.Classes.mol3D import mol3D
 
 
 def multitcgen(args, strfiles):
+    """Generate multiple terachem input files at once.
+        
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+        
+        Returns
+        -------
+            jobdirs : list
+                List of job directories with terachem input files.
+
+    """
+
     jobdirs = []
     method = False
     if args.method and len(args.method) > 1:
@@ -35,23 +44,35 @@ def multitcgen(args, strfiles):
             try:
                 os.remove(xyzf+'.molinp')
                 os.remove(xyzf+'.report')
-            except:
+            except FileNotFoundError:
                 pass
             if not args.reportonly:
                 try:
                     os.remove(xyzf+'.xyz')
-                except:
+                except FileNotFoundError:
                     pass
     return jobdirs
 
-# Generate terachem input files
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @param method Method (e.g. b3lyp)
-#  @return List of job directories
-
 
 def tcgen(args, strfiles, method):
+    """Generate a single terachem input file.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            method : str
+                Name of method to use, (e.g. B3LYP).
+        
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with terachem input file.
+
+    """
+
     # global variables
     # print('----- args provided to tc gen --------')
     # print(args)
@@ -102,7 +123,7 @@ def tcgen(args, strfiles, method):
             try:
                 shutil.copy2(xyzf.replace('.xyz', '.report'),
                              mdir.replace('.xyz', '.report'))
-            except:
+            except FileNotFoundError:
                 pass
         elif args.jobdir:
             jobdirs.append(rdir)
@@ -148,7 +169,7 @@ def tcgen(args, strfiles, method):
         jobparams['charge'] = args.charge
     # Check for existence of basis and sanitize name
     if args.basis:
-        ecp = False  # Flag not currently used, for deciding gpus_ecp code or not later. Can always specify with 'extra' command
+        # ecp = False  # Flag not currently used, for deciding gpus_ecp code or not later. Can always specify with 'extra' command
         if '*' in args.basis:
             jobparams['basis'] = args.basis.replace('*', 's')
         else:
@@ -184,7 +205,7 @@ def tcgen(args, strfiles, method):
                 output.write('%s %s\n' % (keys, jobparams[keys]))
             if jobparams['run'] == 'minimize':
                 output.write('new_minimizer yes\n')
-                #output.write('min_coordinates cartesian\n')
+                # output.write('min_coordinates cartesian\n')
             if args.tc_fix_dihedral:
                 temp = mol3D()
                 temp.readfromxyz(strfiles[i])
@@ -212,7 +233,7 @@ def tcgen(args, strfiles, method):
                 output.write('%s %s\n' % (keys, jobparams[keys]))
             if jobparams['run'] == 'minimize':
                 output.write('new_minimizer yes\n')
-                #output.write('min_coordinates cartesian\n')
+                # output.write('min_coordinates cartesian\n')
             if args.tc_fix_dihedral:
                 temp = mol3D()
                 temp.readfromxyz(strfiles[i])
@@ -229,25 +250,45 @@ def tcgen(args, strfiles, method):
             output.close()
     return jobdirs
 
-# Converts normal xyz file to gxyz (GAMESS format) file
-#  @param filename Filename of xyz file
-#  @return Filename of gxyz file
-
 
 def xyz2gxyz(filename):
+    """Turn an XYZ file into a GAMESS XYZ file.
+
+        Parameters
+        ----------
+            filename : str
+                Filename of xyz file.
+        
+        Returns
+        -------
+            gfilename : str
+                Filename of GAMESS xyz file.
+
+    """
+
     mol = mol3D()  # create mol3D object
     mol.readfromxyz(filename)  # read molecule
     gfilename = filename.replace('.xyz', '.gxyz')  # new file name
     mol.writegxyz(gfilename)  # write gamess formatted xyz file
     return gfilename.split('.gxyz')[0]
 
-# Generate multiple GAMESS runs if multiple methods requested
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @return List of job directories
-
 
 def multigamgen(args, strfiles):
+    """Generate multiple GAMESS files, loops over methods.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+        
+        Returns
+        -------
+            jobdirs : list
+                List of job directories with GAMESS input files.
+
+    """
     method = False
     jobdirs = []
     if args.method and len(args.method) > 1:
@@ -263,15 +304,26 @@ def multigamgen(args, strfiles):
         os.remove(xyzf+'.molinp')
     return jobdirs
 
-# Generate GAMESS input files
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @param method Method (e.g. b3lyp)
-#  @return List of job directories
-
 
 def gamgen(args, strfiles, method):
-    # get global variables
+    """Generate a single GAMESS input file.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            method : str
+                Name of method to use, (e.g. B3LYP).
+        
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with GAMESS input file.
+
+    """
+
     globs = globalvars()
     jobdirs = []
     coordfs = []
@@ -317,7 +369,7 @@ def gamgen(args, strfiles, method):
         try:
             shutil.copy2(xyzf.replace('.xyz', '.report'),
                          mdir.replace('.xyz', '.report'))
-        except:
+        except FileNotFoundError:
             pass
 
     if method:
@@ -431,19 +483,29 @@ def gamgen(args, strfiles, method):
         output.close()
     return jobdirs
 
-# Generate multiple QChem runs if multiple methods requested
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @return List of job directories
-
 
 def multiqgen(args, strfiles):
+    """Generate multiple QChem input files at once.
+        
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+        
+        Returns
+        -------
+            jobdirs : list
+                List of job directories with QChem input files.
+
+    """
     method = False
     jobdirs = []
     if args.method and len(args.method) > 1:
         methods = args.exchange
         for method in methods:
-            jobdirs.append(qen(args, strfiles, method))
+            jobdirs.append(qgen(args, strfiles, method))
     else:
         jobdirs.append(qgen(args, strfiles, method))
     # remove original files
@@ -453,16 +515,25 @@ def multiqgen(args, strfiles):
         os.remove(xyzf + '.report')
     return jobdirs
 
-# Generate QChem input files
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @param method Method (e.g. b3lyp)
-#  @return List of job directories
-
 
 def qgen(args, strfiles, method):
-    # get global variables
-    globs = globalvars()
+    """Generate a single QChem input file.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            method : str
+                Name of method to use, (e.g. B3LYP).
+        
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with QChem input file.
+
+    """
     jobdirs = []
     coordfs = []
     # Initialize the jobparams dictionary with mandatory/useful keywords.
@@ -506,7 +577,7 @@ def qgen(args, strfiles, method):
         try:
             shutil.copy2(xyzf.replace('.xyz', '.report'),
                          mdir.replace('.xyz', '.report'))
-        except:
+        except FileNotFoundError:
             pass
     # Check for existence of basis and sanitize name
     if args.basis and len(args.basis) > 1:
@@ -568,16 +639,25 @@ def qgen(args, strfiles, method):
         output.close()
     return jobdirs
 
-# Generate MOPAC input files
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @param rootdir Root directory
-#  @return List of job directories
-
 
 def mlpgen(args, strfiles, rootdir):
-    # get global variables
-    globs = globalvars()
+    """Generate MOPAC input files.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            rootdir : str
+                Path of the root directory.
+        
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with MOPAC input file.
+
+    """
     jobdirs = []
     coordfs = []
     # Initialize the jobparams dictionary with mandatory/useful keywords.
@@ -605,8 +685,7 @@ def mlpgen(args, strfiles, rootdir):
         else:
             mdir = rdir+'/'+nametrunc
         jobdirs.append(mdir)
-#        shutil.copy2(xyzf,mdir)
-#        shutil.copy2(xyzf.replace('.xyz','.molinp'),mdir.replace('.xyz','.molinp'))
+
     # Just carry over spin and charge keywords if they're set. Could do checks, none for now.
     if args.spin:
         jobparams.append(spin_keywords[int(args.spin)])
@@ -647,13 +726,24 @@ def mlpgen(args, strfiles, rootdir):
         output.close()
     return jobdirs
 
-# Generate multiple ORCA runs if multiple methods requested
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @return List of job directories
-
 
 def multiogen(args, strfiles):
+    """Generate ORCA input files.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with ORCA input files.
+
+    """
+
     method = False
     jobdirs = []
     if args.method and len(args.method) > 0:
@@ -669,17 +759,30 @@ def multiogen(args, strfiles):
                 os.remove(xyzf+'.xyz')
                 os.remove(xyzf+'.molinp')
                 os.remove(xyzf + '.report')
-            except:
+            except FileNotFoundError:
                 pass
     return jobdirs
-# Generate ORCA input files
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @param rootdir Root directory
-#  @return List of job directories
 
 
 def ogen(args, strfiles, method):
+    """Generate a single ORCA input file.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            method : str
+                Method to be used (e.g. B3LYP)
+            
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with ORCA input file.
+
+    """
+
     # global variables
     globs = globalvars()
     jobdirs = []
@@ -722,8 +825,8 @@ def ogen(args, strfiles, method):
             mdir = rdir+'/'+nametrunc+mmd
             if not os.path.exists(mdir):
                 try:
-                    os.mkdirs(mdir)
-                except:
+                    os.makedirs(mdir)
+                except FileExistsError:
                     pass
         if not args.jobdir:
             jobdirs.append(mdir)
@@ -733,7 +836,7 @@ def ogen(args, strfiles, method):
             try:
                 shutil.copy2(xyzf.replace('.xyz', '.report'),
                              mdir.replace('.xyz', '.report'))
-            except:
+            except FileNotFoundError:
                 pass
         elif args.jobdir:
             jobdirs.append(rdir)
@@ -852,14 +955,25 @@ def ogen(args, strfiles, method):
             output.close()
     return jobdirs
 
-# Writeout a single calculation block for ORCA input files
-#  @param output File for writing ORCA input
-#  @param jobparams ORCA input parameters
-#  @param xyzf Name for xyz file
-#  @return List of job directories
-
 
 def ogenwrt(output, jobparams, xyzf):
+    """Generate a single ORCA input file with custom parameters.
+
+        Parameters
+        ----------
+            output : str
+                Filename for writing the ORCA input.
+            jobparams : dict
+                Dictionary of ORCA input parameters.
+            xyzf : str
+                Name for XYZ file.
+            
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with ORCA input file.
+
+    """
     # write the first line of simple keywords
     output.write('!'+jobparams['method']+' ')
     output.write(jobparams['basis']+' ')
@@ -899,14 +1013,25 @@ def ogenwrt(output, jobparams, xyzf):
         '*xyzfile '+str(jobparams['charge'])+' '+str(jobparams['spinmult'])+' '+xyzf+'\n')
     # output.write(''.join(s0)+'*\n')
 
-# Generate MOLCAS input files
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @param rootdir Root directory
-#  @return List of job directories
-
 
 def molcgen(args, strfiles, method):
+    """Generate a single MOLCAS input file.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            method : str
+                Method to be used (e.g. B3LYP)
+            
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with MOLCAS input file.
+
+    """
     # global variables
     globs = globalvars()
     jobdirs = []
@@ -953,8 +1078,8 @@ def molcgen(args, strfiles, method):
             mdir = rdir+'/'+nametrunc+mmd
             if not os.path.exists(mdir):
                 try:
-                    os.mkdirs(mdir)
-                except:
+                    os.makedirs(mdir)
+                except FileExistsError:
                     pass
         if not args.jobdir:
             jobdirs.append(mdir)
@@ -964,7 +1089,7 @@ def molcgen(args, strfiles, method):
             try:
                 shutil.copy2(xyzf.replace('.xyz', '.report'),
                              mdir.replace('.xyz', '.report'))
-            except:
+            except FileNotFoundError:
                 pass
         elif args.jobdir:
             jobdirs.append(rdir)
@@ -994,7 +1119,6 @@ def molcgen(args, strfiles, method):
     if args.basis and args.basis != 'lacvps_ecp':
         jobparams['basis'] = args.basis
     elif (not args.basis) or args.basis == 'lacvps_ecp':
-        temp = mol3D()
         jobparams['basis'] = molcbasis(strfiles, 'ANO-rcc')
     # Overwrite plus add any new dictionary keys from commandline input.
     if args.qoption:
@@ -1051,15 +1175,27 @@ def molcgen(args, strfiles, method):
             output.close()
     return jobdirs
 
-# Writeout a single calculation block for ORCA input files
-#  @param output File for writing ORCA input
-#  @param jobparams ORCA input parameters
-#  @param xyzf Name for xyz file
-#  @param xyzind Index for xyz file in all generated xyz files
-#  @return List of job directories
-
 
 def molcwrt(output, jobparams, xyzf, xyzind):
+    """Generate a single MOLCAS input file with custom parameters.
+
+        Parameters
+        ----------
+            output : str
+                Filename for writing the ORCA input.
+            jobparams : dict
+                Dictionary of ORCA input parameters.
+            xyzf : str
+                Name for XYZ file.
+            xyzind : int
+                Index for xyz file in all generated xyz files
+            
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with ORCA input file.
+
+    """
     # write the gateway block
     output.write('&gateway\n')
     output.write('Coord='+xyzf+'\n')
@@ -1090,13 +1226,23 @@ def molcwrt(output, jobparams, xyzf, xyzind):
         output.write(jobparams['gridtype']+'\n')
         output.write('NPOINTS\n'+jobparams['NPOINTS']+'\n')
 
-# Generate multiple MOLCAS runs if multiple methods requested
-#  @param args Namespace of arguments
-#  @param strfiles List of xyz files produced
-#  @return List of job directories
-
 
 def multimolcgen(args, strfiles):
+    """Generate MOLCAS input files.
+
+        Parameters
+        ----------
+            args : Namespace
+                Namespace of input arguments.
+            strfiles : list
+                List of xyz files produced.
+            
+        Returns
+        -------
+            jobdirs : list
+                List of job directory with ORCA input files.
+
+    """
     method = False
     jobdirs = []
     if args.method and len(args.method) > 0:
@@ -1112,16 +1258,27 @@ def multimolcgen(args, strfiles):
                 os.remove(xyzf+'.xyz')
                 os.remove(xyzf+'.molinp')
                 os.remove(xyzf + '.report')
-            except:
+            except FileNotFoundError:
                 pass
     return jobdirs
-# Generate MOLCAS basis keyword for a given mol3D
-#  @param strfiles List of xyz files produced
-#  @param basistyp The type of basis set
-#  @return String of the basis specification
 
 
 def molcbasis(strfiles, basistyp):
+    """Generate MOLCAS basis keyword for a given mol3D.
+
+        Parameters
+        ----------
+            strfiles : list
+                List of XYZ files produced
+            basistyp : str
+                The basis set.
+            
+        Returns
+        -------
+            basis : str
+                String of basis specification.
+
+    """
     # List of Sets for elem
     # elems[i] contains elements for i-th row
     elems = []
@@ -1185,12 +1342,21 @@ def molcbasis(strfiles, basistyp):
         other than ANO-rcc is not supported yet''')
     return basis
 
-# Determine MOLCAS CASSCF active space for a given mol3D
-#  @param strfiles List of xyz files produced
-#  @return List of the active spaces
-
 
 def molcras2s(strfiles):
+    """Determine MOLCAS CASSCF active space for a given mol3D.
+
+        Parameters
+        ----------
+            strfiles : list
+                List of XYZ files produced
+            
+        Returns
+        -------
+            ras2s : list
+                List of the active spaces
+
+    """
     print('Warning! "ras2" active space is automatically generated and may need adjustment! ')
     ras2s = []
     for i in range(0, len(strfiles)):
@@ -1208,12 +1374,23 @@ def molcras2s(strfiles):
         ras2s.append(ras2)
     return ras2s
 
-# Determine MOLCAS CASSCF active electrons for a given mol3D
-#  @param strfiles List of xyz files produced
-#  @return List of the active spaces
-
 
 def molcnactels(strfiles, oxnum):
+    """Determine MOLCAS CASSCF active electrons for a given mol3D.
+
+        Parameters
+        ----------
+            strfiles : list
+                List of XYZ files produced
+            oxnum : int
+                Oxidation state.
+            
+        Returns
+        -------
+            nactels : list
+                List of the active electrons
+
+    """
     print('Warning! "nactel" is automatically generated and may need adjustment! ')
     nactels = []
     for i in range(0, len(strfiles)):
@@ -1232,12 +1409,21 @@ def molcnactels(strfiles, oxnum):
         nactels.append(nactel)
     return nactels
 
-# Determine MOLCAS CASSCF frozen orbitals for a given mol3D
-#  @param strfiles List of xyz files produced
-#  @return List of the active spaces
-
 
 def molcfrozens(strfiles):
+    """Determine MOLCAS CASSCF frozen orbitals for a given mol3D
+
+        Parameters
+        ----------
+            strfiles : list
+                List of XYZ files produced
+            
+        Returns
+        -------
+            frozens : list
+                List of the frozen orbitals
+
+    """
     frozens = []
     for i in range(0, len(strfiles)):
         frozen = 0
@@ -1255,6 +1441,6 @@ def molcfrozens(strfiles):
                 frozen += 9  # 1s2s2p3s3p
             elif atno > 54:
                 print('Warning! Automatic assignment of "frozen"is not available')
-                print(('for heavy atom like ' + temp.getAtom(ind).symbol()+'yet'))
+                print(('for heavy atom like ' + atom.symbol()+'yet'))
         frozens.append(frozen)
     return frozens
