@@ -5,92 +5,37 @@
 #
 #  Dpt of Chemical Engineering, MIT
 
-from .structgen import *
-from molSimplify.Scripts.molSimplify_io import *
-from molSimplify.Scripts.jobgen import *
-from molSimplify.Scripts.qcgen import *
-from molSimplify.Scripts.isomers import generateisomers
-# from molSimplify.Scripts.tsgen import *
-from molSimplify.Classes.rundiag import *
-import argparse
-import sys
-import os
-import shutil
 import itertools
+import os
 import random
+import shutil
+import sys
 from collections import Counter
-from pkg_resources import resource_filename, Requirement
-import openbabel
+import glob
+
+from molSimplify.Scripts.isomers import generateisomers
+from molSimplify.Scripts.jobgen import (sgejobgen,
+                                        slurmjobgen)
+from molSimplify.Scripts.io import (core_load,
+                                    getlicores,
+                                    lig_load,
+                                    name_complex,
+                                    name_ts_complex,
+                                    substr_load)
+from molSimplify.Scripts.qcgen import (mlpgen,
+                                       multigamgen,
+                                       multimolcgen,
+                                       multiogen,
+                                       multiqgen,
+                                       multitcgen)
+from molSimplify.Scripts.structgen import (structgen)
 
 ###################################################################
 ### define input for cross-compatibility between python 2 and 3 ###
 ###################################################################
 get_input = input
-if sys.version_info[:2] <= (2,7):
-    get_input = raw_input
-    
-#######################################
-### get subset between list1, list2 ###
-#######################################
-
-
-def counterSubset(list1, list2):
-    c1, c2 = Counter(list1), Counter(list2)
-    for k, n in list(c1.items()):
-        if n > c2[k]:
-            return False
-    return True
-
-###############################################
-### get sample aggreeing to the constraints ###
-###############################################
-
-
-def getconstsample(no_rgen, args, licores, coord):
-    samp = []
-    # 4 types of constraints: ligand, ligocc, coord, lignum
-    # get ligand and ligocc
-    get = False
-    occup = []
-    combos = []
-    generated = 0
-    if not coord:
-        coord = 6  # default octahedral
-    # generate all combinations of ligands
-    combos += (list(itertools.combinations_with_replacement(list(range(0, len(licores))), coord)))
-    random.shuffle(combos)
-    for combo in combos:
-        # get total denticity
-        totdent = 0
-        dents = []
-        for l in combo:
-            totdent += int(len(licores[list(licores.keys())[l]][2]))
-            dents.append(int(len(licores[list(licores.keys())[l]][2])))
-        # check for multiple multidentate ligands
-        dsorted = sorted(dents)
-        if not coord or (coord and totdent == coord):
-            if len(dsorted) > 1 and (dsorted[-1]+dsorted[-2] > totdent):
-                generated = generated
-            else:
-                if (args.lignum and len(set(combo)) == int(args.lignum)):
-                    # reorder with high denticity atoms in the beginning
-                    keysl = sorted(list(range(len(dents))),
-                                   key=lambda k: dents[k])
-                    ncombo = [combo[i] for i in keysl]
-                    # add combo
-                    samp.append(ncombo)
-                    generated += 1
-                elif not args.lignum:
-                    # reorder with high denticity atoms in the beginning
-                    keysl = sorted(list(range(len(dents))),
-                                   key=lambda k: dents[k])
-                    ncombo = [combo[i] for i in keysl]
-                    # add combo
-                    samp.append(ncombo)
-                    generated += 1
-            if (generated >= no_rgen):
-                break
-    return samp
+if sys.version_info[:2] <= (2, 7):
+    get_input = raw_input  # noqa: F821
 
 #####################################
 ### constrained random generation ###
@@ -111,9 +56,9 @@ def constrgen(rundir, args, globs):
                                'Random generation started\nGenerating ligand combinations.\n\n'+args.gui.iWtxt.toPlainText())
         args.gui.app.processEvents()
     if args.lig:
-        for i, l in enumerate(args.lig):
-            ligs0.append(l)
-            ligentry, emsg = lig_load(l)  # check ligand
+        for i, li in enumerate(args.lig):
+            ligs0.append(li)
+            ligentry, emsg = lig_load(li)  # check ligand
             # update ligand
             if ligentry:
                 args.lig[i] = ligentry.name
@@ -141,7 +86,7 @@ def constrgen(rundir, args, globs):
                     ligentry.denticity = 1
             if coord:
                 coord -= int(args.ligocc[i])*ligentry.denticity
-            licores.pop(l, None)  # remove from dictionary
+            licores.pop(li, None)  # remove from dictionary
     # check for ligand groups
     licoresnew = dict()
     if args.liggrp and 'all' != args.liggrp.lower():
@@ -168,7 +113,7 @@ def constrgen(rundir, args, globs):
             emsg = rungen(rundir, args, False, globs)
         else:
             if args.gui:
-                from Classes.mWidgets import mQDialogErr
+                from molSimplify.Classes.mWidgets import mQDialogErr
                 qqb = mQDialogErr(
                     'Error', 'No suitable ligand sets were found for random generation. Exiting...')
                 qqb.setParent(args.gui.wmain)
@@ -198,6 +143,56 @@ def constrgen(rundir, args, globs):
         emsg = rungen(rundir, args, False, globs)  # run structure generation
     return args, emsg
 
+
+###############################################
+### get sample aggreeing to the constraints ###
+###############################################
+
+
+def getconstsample(no_rgen, args, licores, coord):
+    samp = []
+    # 4 types of constraints: ligand, ligocc, coord, lignum
+    # get ligand and ligocc
+    combos = []
+    generated = 0
+    if not coord:
+        coord = 6  # default octahedral
+    # generate all combinations of ligands
+    combos += (list(itertools.combinations_with_replacement(list(range(0, len(licores))), coord)))
+    random.shuffle(combos)
+    for combo in combos:
+        # get total denticity
+        totdent = 0
+        dents = []
+        for li in combo:
+            totdent += int(len(licores[list(licores.keys())[li]][2]))
+            dents.append(int(len(licores[list(licores.keys())[li]][2])))
+        # check for multiple multidentate ligands
+        dsorted = sorted(dents)
+        if not coord or (coord and totdent == coord):
+            if len(dsorted) > 1 and (dsorted[-1]+dsorted[-2] > totdent):
+                generated = generated
+            else:
+                if (args.lignum and len(set(combo)) == int(args.lignum)):
+                    # reorder with high denticity atoms in the beginning
+                    keysl = sorted(list(range(len(dents))),
+                                   key=lambda k: dents[k])
+                    ncombo = [combo[i] for i in keysl]
+                    # add combo
+                    samp.append(ncombo)
+                    generated += 1
+                elif not args.lignum:
+                    # reorder with high denticity atoms in the beginning
+                    keysl = sorted(list(range(len(dents))),
+                                   key=lambda k: dents[k])
+                    ncombo = [combo[i] for i in keysl]
+                    # add combo
+                    samp.append(ncombo)
+                    generated += 1
+            if (generated >= no_rgen):
+                break
+    return samp
+
 # Generates multiple runs for different oxidation and spin states
 #  @param rundir Run directory
 #  @param args Namespace of arguments
@@ -205,7 +200,7 @@ def constrgen(rundir, args, globs):
 #  @return Error messages
 
 
-def multigenruns(rundir, args, globs):
+def multigenruns(rundir, args, globs, write_files=True):
     emsg = False
     args.jid = 0  # initilize global name identifier
     multch = False
@@ -232,7 +227,7 @@ def multigenruns(rundir, args, globs):
                 # if args.tsgen:
                 #     emsg = tsgen_supervisor(rundir,args,fname,globs)
                 # else:
-                emsg = rungen(rundir, args, fname, globs)
+                emsg = rungen(rundir, args, fname, globs, write_files=write_files)
                 if emsg:
                     return emsg
     elif (multch):
@@ -247,7 +242,7 @@ def multigenruns(rundir, args, globs):
             # if args.tsgen:
             #     emsg = tsgen_supervisor(rundir,args,fname,globs)
             # else:
-            emsg = rungen(rundir, args, fname, globs)
+            emsg = rungen(rundir, args, fname, globs, write_files=write_files)
             if emsg:
                 return emsg
     elif (multsp):
@@ -259,7 +254,7 @@ def multigenruns(rundir, args, globs):
             # if args.tsgen:
             #     emsg = tsgen_supervisor(rundir,args,fname,globs)
             # else:
-            emsg = rungen(rundir, args, fname, globs)
+            emsg = rungen(rundir, args, fname, globs, write_files=write_files)
             if emsg:
                 return emsg
     elif args.isomers or args.stereos:
@@ -303,7 +298,7 @@ def multigenruns(rundir, args, globs):
             print(('******************* Generating isomer ' +
                   str(counter+1) + '! *******************'))
             print('**************************************************************')
-            emsg = rungen(rundir, args, fname, globs)
+            emsg = rungen(rundir, args, fname, globs, write_files=write_files)
         return emsg
     else:
         if args.charge:
@@ -313,7 +308,7 @@ def multigenruns(rundir, args, globs):
         # if args.tsgen:
         #     emsg = tsgen_supervisor(rundir,args,fname,globs)
         # else:
-        emsg = rungen(rundir, args, fname, globs)
+        emsg = rungen(rundir, args, fname, globs, write_files=write_files)
     return emsg
 
 # Check for multiple ligands specified in one file
@@ -377,9 +372,9 @@ def draw_supervisor(args, rundir):
     if args.lig:
         print('Due to technical limitations, we will draw only the first ligand.')
         print('To view multiple ligands at once, consider using the GUI instead.')
-        l = args.lig[0]
-        lig, emsg = lig_load(l)
-        lig.draw_svg(l)
+        li = args.lig[0]
+        lig, emsg = lig_load(li)
+        lig.draw_svg(li)
     elif args.core:
         if len(args.core) > 1:
             print('Due to technical limitations, we will draw only the first core.')
@@ -406,11 +401,9 @@ def draw_supervisor(args, rundir):
 #  @return Error messages
 
 
-def rungen(rundir, args, chspfname, globs):
+def rungen(rundir, args, chspfname, globs, write_files=True):
     try:
-        from Classes.mWidgets import qBoxFolder
         from Classes.mWidgets import mQDialogInf
-        from Classes.mWidgets import mQDialogErr
     except ImportError:
         args.gui = False
     emsg = False
@@ -505,8 +498,8 @@ def rungen(rundir, args, chspfname, globs):
         if rootcheck and os.path.isdir(rootcheck) and not args.checkdirt and not skip:
             args.checkdirt = True
             if not args.rprompt:
-                flagdir = get_input('\nDirectory '+rootcheck +
-                                ' already exists. Keep both (k), replace (r) or skip (s) k/r/s: ')
+                flagdir = get_input('\nDirectory ' + rootcheck +
+                                    ' already exists. Keep both (k), replace (r) or skip (s) k/r/s: ')
                 if 'k' in flagdir.lower():
                     flagdir = 'keep'
                 elif 's' in flagdir.lower():
@@ -514,8 +507,8 @@ def rungen(rundir, args, chspfname, globs):
                 else:
                     flagdir = 'replace'
             else:
-                #qqb = qBoxFolder(args.gui.wmain,'Folder exists','Directory '+rootcheck+' already exists. What do you want to do?')
-                #flagdir = qqb.getaction()
+                # qqb = qBoxFolder(args.gui.wmain,'Folder exists','Directory '+rootcheck+' already exists. What do you want to do?')
+                # flagdir = qqb.getaction()
                 flagdir = 'replace'
                 # replace existing directory
             if (flagdir == 'replace'):
@@ -537,7 +530,7 @@ def rungen(rundir, args, chspfname, globs):
             args.checkdirt = True
             try:
                 os.mkdir(rootcheck)
-            except:
+            except FileExistsError:
                 print(('Directory '+rootcheck+' can not be created. Exiting..\n'))
                 return
             # check for actual directory
@@ -553,8 +546,8 @@ def rungen(rundir, args, chspfname, globs):
                 else:
                     flagdir = 'replace'
             else:
-                #qqb = qBoxFolder(args.gui.wmain,'Folder exists','Directory '+rootdir+' already exists. What do you want to do?')
-                #flagdir = qqb.getaction()
+                # qqb = qBoxFolder(args.gui.wmain,'Folder exists','Directory '+rootdir+' already exists. What do you want to do?')
+                # flagdir = qqb.getaction()
                 flagdir = 'replace'
             # replace existing directory
             if (flagdir == 'replace'):
@@ -572,8 +565,9 @@ def rungen(rundir, args, chspfname, globs):
                 os.mkdir(rootdir)
         elif not os.path.isdir(rootdir) or not args.checkdirb and not skip:
             if not os.path.isdir(rootdir):
-                args.checkdirb = True
-                os.mkdir(rootdir)
+                if write_files:
+                    args.checkdirb = True
+                    os.mkdir(rootdir)
             ####################################
             ############ GENERATION ############
             ####################################
@@ -586,14 +580,14 @@ def rungen(rundir, args, chspfname, globs):
                 args.ffoption = 'ba'
                 args.MLbonds = False
                 strfiles, emsg, this_diag = structgen(
-                    args, rootdir, ligands, ligocc, globs, mcount)
+                    args, rootdir, ligands, ligocc, globs, mcount, write_files=write_files)
                 for strf in strfiles:
                     tstrfiles.append(strf+'FFML')
                     os.rename(strf+'.xyz', strf+'FFML.xyz')
                 # generate xyz with FF and covalent
                 args.MLbonds = ['c' for i in range(0, len(args.lig))]
                 strfiles, emsg, this_diag = structgen(
-                    args, rootdir, ligands, ligocc, globs, mcount)
+                    args, rootdir, ligands, ligocc, globs, mcount, write_files=write_files)
                 for strf in strfiles:
                     tstrfiles.append(strf+'FFc')
                     os.rename(strf+'.xyz', strf+'FFc.xyz')
@@ -602,14 +596,14 @@ def rungen(rundir, args, chspfname, globs):
                 args.MLbonds = False
                 # generate xyz without FF and trained ML
                 strfiles, emsg, this_diag = structgen(
-                    args, rootdir, ligands, ligocc, globs, mcount)
+                    args, rootdir, ligands, ligocc, globs, mcount, write_files=write_files)
                 for strf in strfiles:
                     tstrfiles.append(strf+'ML')
                     os.rename(strf+'.xyz', strf+'ML.xyz')
                 args.MLbonds = ['c' for i in range(0, len(args.lig))]
                 # generate xyz without FF and covalent ML
                 strfiles, emsg, this_diag = structgen(
-                    args, rootdir, ligands, ligocc, globs, mcount)
+                    args, rootdir, ligands, ligocc, globs, mcount, write_files=write_files)
                 for strf in strfiles:
                     tstrfiles.append(strf+'c')
                     os.rename(strf+'.xyz', strf+'c.xyz')
@@ -617,9 +611,9 @@ def rungen(rundir, args, chspfname, globs):
             else:
                 # generate xyz files
                 strfiles, emsg, this_diag = structgen(
-                    args, rootdir, ligands, ligocc, globs, mcount)
+                    args, rootdir, ligands, ligocc, globs, mcount, write_files=write_files)
             # generate QC input files
-            if args.qccode and not emsg:
+            if args.qccode and (not emsg) and write_files:
                 if args.charge and (isinstance(args.charge, list)):
                     args.charge = args.charge[0]
                 if args.spin and (isinstance(args.spin, list)):
@@ -643,13 +637,13 @@ def rungen(rundir, args, chspfname, globs):
                     print(
                         'Only TeraChem, GAMESS, QChem, ORCA, MOLCAS are supported right now.\n')
             # check molpac
-            if args.mopac and not emsg:
+            if args.mopac and (not emsg) and write_files:
                 print('Generating MOPAC input')
                 if globs.debug:
                     print(strfiles)
                 jobdirs = mlpgen(args, strfiles, rootdir)
             # generate jobscripts
-            if args.jsched and (not emsg) and (not args.reportonly):
+            if args.jsched and (not emsg) and (not args.reportonly) and (write_files):
                 if args.jsched in 'SBATCH SLURM slurm sbatch':
                     slurmjobgen(args, jobdirs)
                     print('SLURM jobscripts generated!')
@@ -658,12 +652,8 @@ def rungen(rundir, args, chspfname, globs):
                     print('SGE jobscripts generated!')
 
             elif multidx != -1:  # if ligand input was a list of smiles strings, write good smiles strings to separate list
-                try:
-                    f = open(ligfilename+'-good.smi', 'a')
+                with open(ligfilename+'-good.smi', 'a') as f:
                     f.write(args.lig[0])
-                    f.close()
-                except:
-                    0
         elif not emsg:
             if args.gui:
                 qq = mQDialogInf('Folder skipped', 'Folder ' +
@@ -671,204 +661,7 @@ def rungen(rundir, args, chspfname, globs):
                 qq.setParent(args.gui.wmain)
             else:
                 print(('Folder '+rootdir+' was skipped..\n'))
-    return emsg
-
-# ## Transition state generation
-# #  @param rundir Run directory
-# #  @param args Namespace of arguments
-# #  @param chspfname Folder name for charges and spins
-# #  @param globs Global variables
-# #  @return Error messages
-# def tsgen_supervisor(rundir,args,chspfname,globs):
-# 	emsg = False
-# 	# load specified core into a mol3D object
-# 	cc, emsg = core_load(args.core)
-# 	if emsg:
-# 		return emsg
-# 	cc.convert2mol3D()
-# 	subcores = getsubcores()
-# 	# load substrate molecule into a mol3D object
-# 	if len(args.substrate) > 1:
-# 		print('Currently only one substrate molecule is supported. Exiting...')
-# 		return
-# 	else:
-# 		substr, emsg = substr_load(args.substrate[0],subcores)
-# 	if emsg:
-# 		return emsg
-# 	substr.convert2mol3D()
-# 	##### fetch smart name
-# 	fname = name_TS(rundir,args.core,substr,args,bind=args.bind,bsmi=args.nambsmi)
-# 	if globs.debug:
-# 		print('fname is ' + str(fname))
-# 	rootdir = fname
-# 	# check for charges/spin
-# 	rootcheck = False
-# 	if (chspfname):
-# 		rootcheck = rootdir
-# 		rootdir = rootdir + '/'+chspfname
-# 	if (args.suff):
-# 		rootdir += args.suff
-# 	# check for mannual overwrite of
-# 	# directory name
-# 	if args.jobdir:
-# 		rootdir = rundir + args.jobdir
-# 	# check for top directory
-# 	skip = False
-# 	if  rootcheck and os.path.isdir(rootcheck) and not args.checkdirt and not skip:
-# 		args.checkdirt = True
-# 		if not args.rprompt:
-# 			flagdir=raw_input('\nDirectory '+rootcheck +' already exists. Keep both (k), replace (r) or skip (s) k/r/s: ')
-# 			if 'k' in flagdir.lower():
-# 				flagdir = 'keep'
-# 			elif 's' in flagdir.lower():
-# 					flagdir = 'skip'
-# 			else:
-# 				flagdir = 'replace'
-# 		else:
-# 			flagdir = 'replace'
-# 			# replace existing directory
-# 		if (flagdir=='replace'):
-# 			shutil.rmtree(rootcheck)
-# 			os.mkdir(rootcheck)
-# 		# skip existing directory
-# 		elif flagdir=='skip':
-# 			skip = True
-# 		# keep both (default)
-# 		else:
-# 			ifold = 1
-# 			while glob.glob(rootdir+'_'+str(ifold)):
-# 				ifold += 1
-# 				rootcheck += '_'+str(ifold)
-# 				os.mkdir(rootcheck)
-# 	elif rootcheck and (not os.path.isdir(rootcheck) or not args.checkdirt) and not skip:
-# 		if globs.debug:
-# 			print('rootcheck is  ' + str(rootcheck))
-# 		args.checkdirt = True
-# 		try:
-# 			os.mkdir(rootcheck)
-# 		except:
-# 			print 'Directory '+rootcheck+' can not be created. Exiting..\n'
-# 			return
-# 	# check for actual directory
-# 	if os.path.isdir(rootdir) and not args.checkdirb and not skip and not args.jobdir:
-# 		args.checkdirb = True
-# 		if not args.rprompt:
-# 			flagdir=raw_input('\nDirectory '+rootdir +' already exists. Keep both (k), replace (r) or skip (s) k/r/s: ')
-# 			if 'k' in flagdir.lower():
-# 				flagdir = 'keep'
-# 			elif 's' in flagdir.lower():
-# 					flagdir = 'skip'
-# 			else:
-# 				flagdir = 'replace'
-# 		else:
-# 			#qqb = qBoxFolder(args.gui.wmain,'Folder exists','Directory '+rootdir+' already exists. What do you want to do?')
-# 			#flagdir = qqb.getaction()
-# 			flagdir = 'replace'
-# 		# replace existing directory
-# 		if (flagdir=='replace'):
-# 			shutil.rmtree(rootdir)
-# 			os.mkdir(rootdir)
-# 		# skip existing directory
-# 		elif flagdir=='skip':
-# 			skip = True
-# 		# keep both (default)
-# 		else:
-# 			ifold = 1
-# 			while glob.glob(rootdir+'_'+str(ifold)):
-# 				ifold += 1
-# 			rootdir += '_'+str(ifold)
-# 			os.mkdir(rootdir)
-# 	elif not os.path.isdir(rootdir) or not args.checkdirb and not skip:
-# 		if not os.path.isdir(rootdir):
-# 			args.checkdirb = True
-# 			os.mkdir(rootdir)
-# 	####################################
-# 	############ GENERATION ############
-# 	####################################
-# 	# determine TS generation mode/reaction type
-# 	# 1: oxidative addition of a single group to an unsaturated complex (e.g., Fe(II) + O2 -> Fe(III)-O-O)
-# 	# 2: oxidative addition of two groups to an unsaturated complex (e.g., Pd + CH4 -> Pd(H)(CH3))
-# 	# 3: abstraction (ligand only reaction) (e.g., Fe(IV)=O + CH4 -> Fe(III)-OH + CH3)
-# 	# 1: compreact is the metal center, substreact is one atom
-# 	# 2: compreact is the metal center, substreact is two bonded atoms
-# 	# 3: compreact is not the metal center and bonded to only one atom, substreact is one atom
-# 	if len(args.compreact) == 1:
-# 		compreact = int(args.compreact[0]) - 1 # one-indexed in input
-# 	else:
-# 		print('Error: Currently only one complex reacting atom is supported. Exiting...')
-# 		return
-# 	if cc.getAtom(compreact).ismetal():
-# 		if len(args.substreact) == 1:
-# 			substreact = int(args.substreact[0]) - 1 # one-indexed in input
-# 			if len(substr.getBondedAtoms(substreact)) == 1:
-# 				if len(cc.getBondedAtomsOct(compreact)) < 6:
-# 					mode = 1
-# 					print('Mode 1: oxidative addition of a single group')
-# 				else:
-# 					print('Error: You have specified oxidative addition of a single group, but the metal atom is not unsaturated. Please check your input. Exiting...')
-# 					return
-# 			else:
-# 				print('Error: You have specified oxidative addition of a single group, but the substrate atom is not terminal. Please check your input. Exiting...')
-# 				return
-# 		elif len(args.substreact) == 2:
-# 			if int(args.substreact[1]) in substr.getBondedAtoms(int(args.substreact[0])):
-# 				if len(cc.getBondedAtomsOct(compreact)) < 5:
-# 					substreact = [int(i) - 1 for i in args.substreact] # one-indexed in input
-# 					mode = 2
-# 					print('Mode 2: oxidative addition of two groups')
-# 				else:
-# 					print('Error: You have specified oxidative addition of two groups, but the metal atom does not have two available empty sites. Please check your input. Exiting...')
-# 					return
-# 			else:
-# 				print('Error: You have specified oxidative addition of two groups, but the two substrate groups are not bonded. Please check your input. Exiting...')
-# 				return
-# 	elif len(cc.getBondedAtoms(compreact)) == 1:
-# 		if len(args.substreact) == 1:
-# 			substreact = int(args.substreact[0]) - 1 # one-indexed in input
-# 		else:
-# 			print('Error: You have specified abstraction, but specified more than one substrate atom. Please check your input. Exiting...')
-# 			return
-# 		if len(substr.getBondedAtoms(substreact)) == 1:
-# 			mode = 3
-# 			print('Mode 3: Abstraction')
-# 		else:
-# 			print('Error: You have specified abstraction, but the substrate atom is not terminal. Please check your input. Exiting...')
-# 			return
-# 	else:
-# 		print('Error: You have specified abstraction, but the abstracting atom is not terminal. Please check your input. Exiting...')
-# 		return
-# 	if not skip:
-# 		# generate xyz files
-# 		strfiles,emsg,this_diag = tsgen(mode,args,rootdir,cc,substr,compreact,substreact,globs)
-# 		# generate QC input files
-# 		if args.qccode and not emsg:
-# 			args.runtyp = 'ts'
-# 			if args.charge and (isinstance(args.charge, list)):
-# 				args.charge = args.charge[0]
-# 			if args.spin and (isinstance(args.spin, list)):
-# 				args.spin = args.spin[0]
-# 			if args.qccode.lower() in 'terachem tc Terachem TeraChem TERACHEM TC':
-# 				jobdirs = multitcgen(args,strfiles)
-# 				print 'TeraChem input files generated!'
-# 			elif 'gam' in args.qccode.lower():
-# 				jobdirs = multigamgen(args,strfiles)
-# 				print 'GAMESS input files generated!'
-# 			elif 'qch' in args.qccode.lower():
-# 				jobdirs = multiqgen(args,strfiles)
-# 				print 'QChem input files generated!'
-# 			else:
-# 				print 'Only TeraChem, GAMESS and QChem are supported right now.\n'
-# 		# generate jobscripts
-# 		if args.jsched and not emsg:
-# 			if args.jsched in 'SBATCH SLURM slurm sbatch':
-# 				slurmjobgen(args,jobdirs)
-# 				print 'SLURM jobscripts generated!'
-# 			elif args.jsched in 'SGE Sungrid sge':
-# 				sgejobgen(args,jobdirs)
-# 				print 'SGE jobscripts generated!'
-# 		if this_diag.sanity: # move to separate subdirectory if generated structure was bad
-# 			fname = rootdir.rsplit('/',1)[-1]
-# 			shutil.move(rootdir,rundir+'/badjobs/'+fname)
-# 	elif not emsg:
-# 		print 'Folder '+rootdir+' was skipped..\n'
-# 	return emsg
+    if write_files:
+        return emsg  # Default behavior
+    else:
+        return strfiles, emsg, this_diag  # Assume that user wants these if they're not writing files
