@@ -5,7 +5,6 @@ import numpy as np
 import subprocess
 import pandas as pd
 import shutil
-import time
 from molSimplify.job_manager.classes import resub_history, textfile
 from ast import literal_eval
 import json
@@ -15,7 +14,7 @@ def try_float(obj):
     # Converts an object to a floating point if possible
     try:
         floating_point = float(obj)
-    except:
+    except ValueError:
         floating_point = obj
     return floating_point
 
@@ -31,7 +30,6 @@ def read_outfile(outfile_path, short_ouput=False, long_output=True):
     ## Reads TeraChem and ORCA outfiles
     #  @param outfile_path complete path to the outfile to be read, as a string
     #  @return A dictionary with keys finalenergy,s_squared,s_squared_ideal,time
-
     output = textfile(outfile_path)
     output_type = output.wordgrab(['TeraChem', 'ORCA'], ['whole_line', 'whole_line'])
     # print("output_type: ", output_type)
@@ -43,8 +41,24 @@ def read_outfile(outfile_path, short_ouput=False, long_output=True):
                 print('Warning! Nohup file caught in outfile processing')
                 print(outfile_path)
                 counter = 0
+            elif 'smd.out' in outfile_path:
+                print('Warning! SMD file caught in outfile processing')
+                print(outfile_path)
+                counter = 0
+            elif ('atom' in outfile_path) and ('ORCA' in output_type):
+                print('Density fitting output caught in outfile processing')
+                print(outfile_path)
+                counter = 0
             else:
-                raise ValueError('.out file type not recognized for file: ' + outfile_path)
+                print('.out file type not recognized for file: ' + outfile_path)
+                return_dict = {'name': None, 'charge': None, 'finalenergy': None,
+                               'time': None, 's_squared': None, 's_squared_ideal': None,
+                               'finished': False, 'min_energy': None, 'scf_error': False,
+                               'thermo_grad_error': False, 'solvation_energy': None, 'optimization_cycles': None,
+                               'thermo_vib_energy': None, 'thermo_vib_free_energy': None, 'thermo_suspect': None,
+                               'orbital_occupation': None, 'oscillating_scf_error': False}
+                return return_dict
+                
     output_type = ['TeraChem', 'ORCA'][counter]
 
     name = None
@@ -109,10 +123,15 @@ def read_outfile(outfile_path, short_ouput=False, long_output=True):
         min_energy = output.wordgrab('FINAL', 2, min_value=True)[0]
 
         is_finished = output.wordgrab(['finished:'], 'whole_line', last_line=True)[0]
-        if is_finished:
+        if is_finished:  # for full optimization
             if is_finished[0] == 'Job' and is_finished[1] == 'finished:':
                 finished = True
 
+        is_finished = output.wordgrab(['processing'], 'whole_line', last_line=True)[0]
+        if is_finished:  # for hydrogen optimization
+            if is_finished[0] == 'Total' and is_finished[1] == 'processing':
+                finished = True
+
         is_scf_error = output.wordgrab('DIIS', 5, matching_index=True)[0]
         if is_scf_error[0]:
             is_scf_error = [output.lines[i].split() for i in is_scf_error]
@@ -161,8 +180,9 @@ def read_outfile(outfile_path, short_ouput=False, long_output=True):
                     + float(timekey[9])
                     + float(timekey[11]) * 0.001)
 
-        charge = output.wordgrab(['Sum of atomic charges         :'], [-1], last_line=True)[0]
-        charge = int(round(charge, 0))  # Round to nearest integer value (it should always be very close)
+        if finished:
+            charge = output.wordgrab(['Total Charge'], [-1], last_line=True)[0]
+            charge = int(round(charge, 0))  # Round to nearest integer value (it should always be very close)
 
         opt_energies = output.wordgrab('FINAL SINGLE POINT ENERGY', -1)[0]
         geo_opt_cycles, min_energy = len(opt_energies), min(opt_energies)
@@ -185,6 +205,7 @@ def read_outfile(outfile_path, short_ouput=False, long_output=True):
     return_dict['thermo_suspect'] = thermo_suspect
     return_dict['orbital_occupation'] = orbital_occupation
     return_dict['oscillating_scf_error'] = oscillating_scf_error
+    return_dict['outfile_path'] = outfile_path
     return return_dict
 
 
@@ -193,6 +214,7 @@ def read_infile(outfile_path):
     # Returns a dictionary of the job settings included in that infile
 
     root = outfile_path.rsplit('.', 1)[0]
+    unique_job_name = os.path.split(root)[-1]
     inp = textfile(root + '.in')
     if '#ORCA' in inp.lines[0]:
         qm_code = 'orca'
@@ -200,13 +222,19 @@ def read_infile(outfile_path):
         qm_code = 'terachem'
 
     if qm_code == 'terachem':
-        charge, spinmult, solvent, run_type, levelshifta, levelshiftb, method, hfx, basis, dispersion, coordinates, guess = inp.wordgrab(
+        # account for multiple keywords for dispersion
+        disp0 = inp.wordgrab(['dispersion '], [1], last_line=True)
+        disp1 = inp.wordgrab(['dftd '], [1], last_line=True)
+        if disp0 != [None]:
+            dispersion = disp0[0]
+        else:
+            dispersion = disp1[0]
+        charge, spinmult, solvent, run_type, levelshifta, levelshiftb, method, hfx, basis, coordinates, guess = inp.wordgrab(
             ['charge ', 'spinmult ', 'epsilon ',
              'run ', 'levelshiftvala ',
              'levelshiftvalb ', 'method ',
-             'HFX ', 'basis ', 'dispersion ',
-             'coordinates ', 'guess '],
-            [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
+             'HFX ', 'basis ', 'coordinates ', 'guess '],
+            [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
             last_line=True)
         charge, spinmult = int(charge), int(spinmult)
         if guess:
@@ -277,10 +305,10 @@ def read_infile(outfile_path):
 
     return_dict = {}
 
-    for prop, prop_name in zip([root,charge, spinmult, solvent, run_type, levelshifta, levelshiftb, method, hfx,
+    for prop, prop_name in zip([unique_job_name, charge, spinmult, solvent, run_type, levelshifta, levelshiftb, method, hfx,
                                 basis, convergence_thresholds, multibasis, constraints, dispersion, coordinates, guess,
                                 qm_code],
-                               ['name','charge', 'spinmult', 'solvent', 'run_type', 'levelshifta', 'levelshiftb', 
+                               ['name', 'charge', 'spinmult', 'solvent', 'run_type', 'levelshifta', 'levelshiftb', 
                                 'method', 'hfx',
                                 'basis', 'convergence_thresholds', 'multibasis', 'constraints', 'dispersion',
                                 'coordinates', 'guess', 'qm_code']):
@@ -311,15 +339,13 @@ def read_configure(home_directory, outfile_path):
             return configure
         else:
             return []
-
     home_configure = load_configure_file(home_directory)
     if outfile_path:
         local_configure = load_configure_file(os.path.split(outfile_path)[0])
     else:
         local_configure = []
-
     # Determine which derivative jobs are requested
-    solvent, vertEA, vertIP, thermo, dissociation, hfx_resample, functionalsSP = False, False, False, False, False, False, False
+    solvent, vertEA, vertIP, thermo, dissociation, hfx_resample, functionalsSP, mbe = False, False, False, False, False, False, False, False
     for line in home_configure + local_configure:
         if 'solvent' in line or 'Solvent' in line:
             solvent = [float(p) for p in line.split()[1:]]
@@ -329,17 +355,20 @@ def read_configure(home_directory, outfile_path):
             vertIP = True
         if 'functionalsSP' in line or 'FunctionalsSP' in line:
             functionalsSP = [str(p) for p in line.split()[1:]]
-        if 'thermo' in line or 'Thermo' in line:
+        if ('thermo' in line and 'thermo_grad_error' not in line) or ('Thermo' in line and 'Thermo_grad_error' not in line):
             thermo = True
         if 'dissociation' in line or 'Dissociation' in line:
             dissociation = True
         if 'hfx_resample' in line or 'HFX_resample' in line:
             hfx_resample = True
+        if 'mbe' in line or "MBE" in line:
+            mbe = True
 
     # Determine global settings for this run
     max_jobs, max_resub, levela, levelb, method, hfx, geo_check, sleep, job_recovery, dispersion = False, False, False, False, False, False, False, False, [], False
     ss_cutoff, hard_job_limit, use_molscontrol, general_sp = False, False, False, False
-    dissociated_ligand_charges,dissociated_ligand_spinmults = {},{}
+    run_psi4, psi4_config = False, {}
+    dissociated_ligand_charges, dissociated_ligand_spinmults = {}, {}
     for configure in [home_configure, local_configure]:
         for line in configure:
             if 'max_jobs' in line.split(':'):
@@ -376,17 +405,30 @@ def read_configure(home_directory, outfile_path):
             if "use_molscontrol" in line.split(':'):
                 use_molscontrol = bool(int(line.split(":")[-1]))
             if "general_sp" in line.split(':'):
+                print("general SP jobs activated.")
                 localpath = line.split(":")[-1].replace(" ", "")
                 if os.path.isfile(localpath):
                     with open(os.getcwd() + "/" + localpath, "r") as f:
                         try:
                             general_sp = json.load(f)
-                        except:
+                        except json.JSONDecodeError:
+                            raise ValueError("%s is not a valid json file." % localpath)
+                else:
+                    raise ValueError("%s does not exits." % localpath)
+            if "run_psi4" in line.split(':'):
+                print("Psi4 jobs activated.")
+                run_psi4 = True
+                localpath = line.split(":")[-1].replace(" ", "")
+                if os.path.isfile(localpath):
+                    with open(os.getcwd() + "/" + localpath, "r") as f:
+                        try:
+                            psi4_config = json.load(f)
+                        except json.JSONDecodeError:
                             raise ValueError("%s is not a valid json file." % localpath)
                 else:
                     raise ValueError("%s does not exits." % localpath)
     # If global settings not specified, choose defaults:
-    if not max_jobs:
+    if (not max_jobs) and isinstance(max_jobs, bool):
         max_jobs = 50
     if not max_resub:
         max_resub = 5
@@ -402,7 +444,7 @@ def read_configure(home_directory, outfile_path):
         sleep = 7200
     if not ss_cutoff:
         ss_cutoff = 1.0
-    if not hard_job_limit:
+    if (not hard_job_limit):
         hard_job_limit = 190
 
     return {'solvent': solvent, 'vertEA': vertEA, 'vertIP': vertIP, 'thermo': thermo, 'dissociation': dissociation,
@@ -412,7 +454,8 @@ def read_configure(home_directory, outfile_path):
             'ss_cutoff': ss_cutoff, 'hard_job_limit': hard_job_limit,
             'dissociated_ligand_spinmults': dissociated_ligand_spinmults,
             'dissociated_ligand_charges': dissociated_ligand_charges,
-            "use_molscontrol": use_molscontrol, "general_sp": general_sp}
+            "use_molscontrol": use_molscontrol, "general_sp": general_sp,
+            "run_psi4": run_psi4, "psi4_config": psi4_config, 'mbe': mbe}
 
 
 def read_charges(PATH):
@@ -458,12 +501,9 @@ def write_input(input_dictionary=dict(), name=None, charge=None, spinmult=None,
                 convergence_thresholds=None, basis='lacvps_ecp', hfx=None, constraints=None,
                 multibasis=False, coordinates=False, dispersion=False, qm_code='terachem',
                 parallel_environment=4, precision='dynamic', dftgrid=1, dynamicgrid='yes',
-                machine = 'gibraltar'):
+                machine='gibraltar'):
     # Writes a generic input file for terachem or ORCA
     # The neccessary parameters can be supplied as arguements or as a dictionary. If supplied as both, the dictionary takes priority
-    # "Custom line" can be used to add additional lines to the infile and is not treated by an input dictionary
-    # Note that the infile dictionary can have an additional key, "name", which is not poulated by read_infile()
-    # If name is specified, the coordinates are generated based on the name, rather than based on the coordinates variable
 
     infile = dict()
     # If the input_dictionary exists,parse it and set the parameters, overwritting other specifications
@@ -482,7 +522,7 @@ def write_input(input_dictionary=dict(), name=None, charge=None, spinmult=None,
             infile[prop_name] = prop
 
     if (not infile['charge'] and infile['charge'] != 0) or (not infile['spinmult'] and infile['spinmult'] != 0) or (
-            not infile['name']):
+            not infile['name']) or (not infile['coordinates']):
         print(('Name: ' + infile['name']))
         print(('Charge: ' + str(infile['charge'])))
         print(('Spinmult: ' + str(infile['spinmult'])))
@@ -506,15 +546,12 @@ def write_terachem_input(infile_dictionary):
     if infile['spinmult'] != 1:
         infile['method'] = 'u' + infile['method']
 
-    if infile['name']:
-        infile['coordinates'] = infile['name']+'.xyz'
-
     input_file = open(infile['name'] + '.in', 'w')
     text = ['levelshiftvalb ' + str(infile['levelshiftb']) + '\n',
             'levelshiftvala ' + str(infile['levelshifta']) + '\n',
             'run ' + infile['run_type'] + '\n',
             'scf diis+a\n',
-            'coordinates ' + infile['coordinates'].replace("#", "3") + '\n',
+            'coordinates ' + infile['coordinates'] + '\n',
             'levelshift yes\n',
             'spinmult ' + str(infile['spinmult']) + '\n',
             'scrdir ./scr\n',
@@ -548,9 +585,10 @@ def write_terachem_input(infile_dictionary):
     if type(infile['convergence_thresholds']) == list:
         if infile['convergence_thresholds'][0]:
             thresholds = [line if line.endswith('\n') else line + '\n' for line in infile['convergence_thresholds']]
-            tight_thresholds = "min_converge_gmax " + thresholds[0] + "min_converge_grms " + thresholds[
-                1] + "min_converge_dmax " + thresholds[2] + "min_converge_drms " + thresholds[3] + "min_converge_e " + \
-                               thresholds[4] + "convthre " + thresholds[5]
+            tight_thresholds = ("min_converge_gmax " + thresholds[0] + "min_converge_grms " 
+                                + thresholds[1] + "min_converge_dmax " + thresholds[2] 
+                                + "min_converge_drms " + thresholds[3] + "min_converge_e "
+                                + thresholds[4] + "convthre " + thresholds[5])
             text = text[:-1] + ['\n', tight_thresholds, 'end']
 
     if infile['dispersion']:
@@ -574,13 +612,12 @@ def write_terachem_input(infile_dictionary):
                             'pcm cosmo\n',
                             'epsilon %.2f\n' % float(infile['solvent']),
                             'pcm_radii read\n',
-                            'pcm_radii_file /home2/harperd/pcm_radii\n',
+                            'pcm_radii_file /home/harperd/pcm_radii\n',
                             'end']
-    
-    if infile['machine'] in ['gibraltar','bridges']:
-        text = text[:-1] + ['nbo yes\n', 'gpus 1\n','end']
+    if infile['machine'] in ['gibraltar', 'bridges']:
+        text = text[:-1] + ['nbo yes\n', 'gpus 1\n', 'end']
     elif infile['machine'] in ['comet']:
-        text = text[:-1] + ['gpus 2\n','end']
+        text = text[:-1] + ['gpus 2\n', 'end']
     else:
         raise ValueError('Machine not known!')
 
@@ -620,17 +657,6 @@ def write_orca_input(infile_dictionary):
     if infile['run_type'] == 'minimize':
         infile['run_type'] = 'opt'
 
-    if infile['name']:
-        infile['coordinates'] = infile['name'] + '.xyz'
-    if not infile['name']:
-        infile['name'] = os.path.split(infile['coordinates'])[-1].rsplit('.', 1)[0]
-
-    # Last bit of infile dictionary prep
-    if infile['name']:
-        infile['coordinates'] = infile['name'] + '.xyz'
-    if not infile['name']:
-        infile['name'] = os.path.split(infile['coordinates'])[-1].rsplit('.', 1)[0]
-
     input_file = open(infile['name'] + '.in', 'w')
     # Note that max core is set to 2000MB, this is 2/3 of the amount allocated in the jobscript (on a per processor basis)
     # The SCF is known (according to the ORCA manual) to exceed allotted memory, so this provides some wiggle room
@@ -659,14 +685,14 @@ def write_orca_input(infile_dictionary):
 
 
 def write_jobscript(name, custom_line=None, time_limit='96:00:00', qm_code='terachem', parallel_environment=4,
-                    machine='gibraltar', cwd=False, use_molscontrol=False):
+                    machine='gibraltar', cwd=False, use_molscontrol=False, queues=['gpus', 'gpusnew']):
     # Writes a generic obscript
     # custom line allows the addition of extra lines just before the export statement
 
     if qm_code == 'terachem':
         write_terachem_jobscript(name, custom_line=custom_line, time_limit=time_limit, 
                                  machine=machine, cwd=cwd,
-                                 use_molscontrol=use_molscontrol)
+                                 use_molscontrol=use_molscontrol, queues=queues)
     elif qm_code == 'orca':
         write_orca_jobscript(name, custom_line=custom_line, time_limit=time_limit,
                              parallel_environment=parallel_environment, 
@@ -677,9 +703,9 @@ def write_jobscript(name, custom_line=None, time_limit='96:00:00', qm_code='tera
 
 
 def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', terachem_line=True, 
-                             machine='gibraltar', cwd=False, use_molscontrol=False):
-    if use_molscontrol and machine is not 'gibraltar':
-        raise ValueError("molscontrol is only implemented on gibraltar for now.")
+                             machine='gibraltar', cwd=False, use_molscontrol=False, queues=['gpus', 'gpusnew']):
+    # if use_molscontrol and machine != 'gibraltar':
+    #     raise ValueError("molscontrol is only implemented on gibraltar for now.")
     jobscript = open(name + '_jobscript', 'w')
     if machine == 'gibraltar':
         if not use_molscontrol:
@@ -689,7 +715,7 @@ def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', tera
                     '#$ -R y\n',
                     '#$ -l h_rt=' + time_limit + '\n',
                     '#$ -l h_rss=8G\n',
-                    '#$ -q gpus|gpusnew|gpusnewer\n',
+                    '#$ -q '+'|'.join(queues)+'\n',
                     '#$ -l gpus=1\n',
                     '#$ -pe smp 1\n',
                     "# -fin " + "%s.in\n" % name,
@@ -706,7 +732,7 @@ def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', tera
                     '#$ -R y\n',
                     '#$ -l h_rt=' + time_limit + '\n',
                     '#$ -l h_rss=8G\n',
-                    '#$ -q gpus|gpusnew|gpusnewer\n',
+                    '#$ -q '+'|'.join(queues)+'\n',
                     '#$ -l gpus=1\n',
                     '#$ -pe smp 1\n',
                     "# -fin " + "%s.in\n" % name,
@@ -796,7 +822,7 @@ def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', tera
                 text += ["PID_KILL=$!\n"]
                 text += ["molscontrol $PID_KILL &\n"]
                 text += ["wait\n"]
-    elif terachem_line and machine in ['bridges','comet']:
+    elif terachem_line and machine in ['bridges', 'comet']:
         text += ['terachem ' + name + '.in ' + '> ' + name + '.out\n']
     if custom_line:
         if type(custom_line) == list:
@@ -835,8 +861,8 @@ def write_orca_jobscript(name, custom_line=None, time_limit='96:00:00', parallel
                 'source /etc/profile.d/modules.sh\n',
                 'module module load intel\n',
                 'module module load orca\n',
-                'export PATH=/home2/harperd/software/openmpi/bin:$PATH\n',
-                'export LD_LIBRARY_PATH=/home2/harperd/software/openmpi/lib:$LD_LIBRARY_PATH\n\n',
+                'export PATH=/home/harperd/software/openmpi/bin:$PATH\n',
+                'export LD_LIBRARY_PATH=/home/harperd/software/openmpi/lib:$LD_LIBRARY_PATH\n\n',
                 '/opt/orca/orca_4_1_2_linux_x86-64_openmpi313/orca ' + name + '.in  > $SGE_O_WORKDIR/' + name + '.out\n\n',
                 'mkdir $SGE_O_WORKDIR/scr\n',
                 'cp ' + name + '.trj $SGE_O_WORKDIR/scr/optim.xyz\n',
