@@ -8,10 +8,20 @@ import molSimplify.job_manager.moltools as moltools
 from molSimplify.job_manager.classes import resub_history
 import molSimplify.job_manager.manager_io as manager_io
 
-# Set machine as global variable
-machine = tools.get_machine()
-
 def load_history(PATH):
+    """Load a resub history object.
+
+    Parameters
+    ----------
+        PATH : str
+            The name of an output file or history object pickle file.
+
+    Returns
+    -------
+        history : resub_history
+            resub_history class instance for history object of job.
+        
+    """
     # takes the path to either an outfile or the resub_history pickle
     # returns the resub_history class object
 
@@ -19,19 +29,45 @@ def load_history(PATH):
     history.read(PATH)
     return history
 
+def abandon_job(PATH):
+    """Abandons a job with a given path. This function is never and should never be called by the job manager.
+    Only called manually for troublesome jobs. 
+
+    Parameters
+    ----------
+        PATH : str
+            The name of an output file or history object pickle file.
+        
+    """
+    # takes the path to either an outfile or the resub_history pickle
+    # sets the jobs status to be abandoned
+
+    # This function is never and should never be called by the job manager.
+    # It is for manually use with particularly troublesome jobs
+    history = load_history(PATH)
+    history.abandon()
+    history.save()
 
-## Archive the scr file so it isn't overwritten in future resubs
-#  @param rewrite_inscr Determines whether to copy this runs wfn and optimized geometry to the inscr directory
 def save_scr(outfile_path, rewrite_inscr=True):
+    """Archive the scr file so it isn't overwritten in future resubs. 
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+        rewrite_inscr : bool, optional
+            Determines whether to copy this runs wfn and optimized geometry to the inscr directory. Default is True.
+
+    Returns
+    -------
+        scrpaths : str
+            Path to new scr directory.
+
+        
+    """
     root = os.path.split(outfile_path)[0]
-    # print("root: ", root)
-    basepath = os.getcwd()
-    # print("basepath: ", basepath)
-    os.chdir(root)
-    root = './'
     scr_path = os.path.join(root, 'scr')
 
-    print("scr_path: ", scr_path)
     if os.path.isdir(scr_path):
         # extract the optimized geometry, if it exists
         optim = glob.glob(os.path.join(scr_path, 'optim.xyz'))
@@ -54,7 +90,7 @@ def save_scr(outfile_path, rewrite_inscr=True):
         # archive the scr under a new name so that we can write a new one
         old_scrs = glob.glob(scr_path + '_*')
         old_scrs = [int(i[-1]) for i in old_scrs]
-        print("old_scrs: ", old_scrs)
+
         if len(old_scrs) > 0:
             new_scr = str(max(old_scrs) + 1)
         else:
@@ -62,15 +98,22 @@ def save_scr(outfile_path, rewrite_inscr=True):
         # print("current_scr: ", scr_path)
         # print("backup_scr: ", scr_path + '_' + new_scr)
         shutil.move(scr_path, scr_path + '_' + new_scr)
-        os.chdir(basepath)
 
         return os.path.join(os.path.split(outfile_path)[0], 'scr') + '_' + new_scr
-    else:
-        os.chdir(basepath)
 
-
-## Save the outfile within the resub_history pickel object
 def save_run(outfile_path, rewrite_inscr=True, save_scr_flag=True):
+    """Save the outfile within the resub_history pickle object. 
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+        rewrite_inscr : bool, optional
+            Determines whether to copy this runs wfn and optimized geometry to the inscr directory. Default is True.
+        save_scr_flag : bool, optional
+            Determine wheether to store scr. Default is True.
+        
+    """
     def write(list_of_lines, path):
         fil = open(path, 'w')
         for i in list_of_lines:
@@ -120,8 +163,15 @@ def save_run(outfile_path, rewrite_inscr=True, save_scr_flag=True):
         write(xyz_lines, 'old_xyz')
         os.chdir(home)
 
-
 def reset(outfile_path):
+    """Returns the run to the state it was after the first run, before job recovery acted on it. 
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+   
+    """
     # Returns the run to the state it was after the first run, before job recovery acted on it
 
     pickle_path = outfile_path.rsplit('.', 1)[0] + '.pickle'
@@ -151,9 +201,9 @@ def reset(outfile_path):
         # remove all files for derivative jobs spawned based on this job
         derivative_types = ['solvent', 'vertEA', 'vertIP', 'thermo', 'kp', 'rm', 'ultratight', 'HFXresampling',
                             'functional']
-        possible = [i for i in glob.glob(os.path.join(os.path.split(outfile_path)[0],'*')) if os.path.isdir(i)]
+        possible = [i for i in glob.glob(os.path.join(os.path.split(outfile_path)[0], '*')) if os.path.isdir(i)]
         for folder in possible:
-            if os.path.split(outfile_path)[1].rsplit('.',1)[0] in folder:
+            if os.path.split(outfile_path)[1].rsplit('.', 1)[0] in folder:
                 derivative = False
                 for typ in derivative_types:
                     if typ in folder:
@@ -161,7 +211,7 @@ def reset(outfile_path):
                 if derivative:
                     shutil.rmtree(folder)
 
-        #rename outfile and jobscript files
+        # rename outfile and jobscript files
         shutil.move(outfile_path, outfile_path[:-4] + '.old')  # rename old out so it isn't found in .out searches
         shutil.move(outfile_path[:-4] + '_jobscript', outfile_path[
                                                       :-4] + '_oldjob')  # rename old jobscript so it isn't thought to be  job that hasn't started yet
@@ -179,7 +229,7 @@ def reset(outfile_path):
             try:
                 shutil.move(path,
                             os.path.join(old_path, str(np.random.randint(999999999)) + '_' + os.path.split(path)[-1]))
-            except:
+            except FileNotFoundError:
                 print('No file found for: ' + path)
 
         # Rewrite the .xyz, .in, jobscript, and .out file to be the same as they were after the first run
@@ -209,8 +259,20 @@ def reset(outfile_path):
         shutil.move(scr_path + '_0', scr_path)
         shutil.move(pickle_path, os.path.join(old_path, str(np.random.randint(999999999)) + '_resub_history'))
 
-
 def simple_resub(outfile_path):
+    """Resubmits a job without changing parameters. Particularly useful for CUDA errors.
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
     # Resubmits a job without changing parameters. Particularly useful for CUDA errors.
     save_run(outfile_path, rewrite_inscr=False)
     history = resub_history()
@@ -224,8 +286,20 @@ def simple_resub(outfile_path):
     tools.qsub(root + '_jobscript')
     return True
 
-
 def clean_resub(outfile_path):
+    """Resubmits a job with default parameters, useful for undoing level shift or hfx alterations.
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
     # Resubmits a job with default parameters, useful for undoing level shift or hfx alterations
     save_run(outfile_path)
     history = resub_history()
@@ -236,6 +310,7 @@ def clean_resub(outfile_path):
     history.needs_resub = False
     history.save()
 
+    machine = tools.get_machine()
     root = outfile_path.rsplit('.', 1)[0]
     name = os.path.split(root)[-1]
     directory = os.path.split(outfile_path)[0]
@@ -273,8 +348,20 @@ def clean_resub(outfile_path):
     tools.qsub(root + '_jobscript')
     return True
 
-
 def resub_spin(outfile_path):
+    """Resubmits a spin contaminated job with blyp to help convergence to a non-spin contaminated solution.
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
     # resubmits a spin contaminated job with blyp to help convergence to a non-spin contaminated solution
     history = resub_history()
     history.read(outfile_path)
@@ -305,6 +392,7 @@ def resub_spin(outfile_path):
         history.notes.append('Spin contaminated, lowering HFX to aid convergence')
         history.save()
 
+        machine = tools.get_machine()
         root = outfile_path.rsplit('.', 1)[0]
         name = os.path.split(root)[-1]
         directory = os.path.split(outfile_path)[0]
@@ -326,8 +414,20 @@ def resub_spin(outfile_path):
     else:
         return False
 
-
 def resub_scf(outfile_path):
+    """Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1).
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
     # Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1)
     history = resub_history()
     history.read(outfile_path)
@@ -353,6 +453,7 @@ def resub_scf(outfile_path):
         history.notes.append('SCF convergence error, level shifts adjusted to aid convergence')
         history.save()
 
+        machine = tools.get_machine()
         root = outfile_path.rsplit('.', 1)[0]
         name = os.path.split(root)[-1]
         directory = os.path.split(outfile_path)[0]
@@ -373,8 +474,21 @@ def resub_scf(outfile_path):
     else:
         return False
 
-
 def resub_oscillating_scf(outfile_path):
+    """Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1).
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
+
     # Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1)
     history = resub_history()
     history.read(outfile_path)
@@ -399,6 +513,7 @@ def resub_oscillating_scf(outfile_path):
         history.notes.append('SCF convergence error, precision and grid adjusted to aid convergence')
         history.save()
 
+        machine = tools.get_machine()
         root = outfile_path.rsplit('.', 1)[0]
         name = os.path.split(root)[-1]
         directory = os.path.split(outfile_path)[0]
@@ -418,8 +533,22 @@ def resub_oscillating_scf(outfile_path):
     else:
         return False
 
-
 def resub_bad_geo(outfile_path, home_directory):
+    """Resubmits a job that's converged to a bad geometry with additional contraints.
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+        home_directory : str
+            Path to the base directory of the run.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
     # Resubmits a job that's converged to a bad geometry with additional contraints
     history = resub_history()
     history.read(outfile_path)
@@ -445,6 +574,7 @@ def resub_bad_geo(outfile_path, home_directory):
         history.notes.append('Bad geometry detected, adding constraints and trying again')
         history.save()
 
+        machine = tools.get_machine()
         root = outfile_path.rsplit('.', 1)[0]
         name = os.path.split(root)[-1]
         directory = os.path.split(outfile_path)[0]
@@ -482,8 +612,21 @@ def resub_bad_geo(outfile_path, home_directory):
     else:
         return False
 
-
 def resub_tighter(outfile_path):
+    """Resubmits a thermo job with the gradient error problem. Finds the parent job and resubmits it with a tighter scf 
+    convergence criteria.
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
     # Takes the path to the outfile of a thermo job with the gradient error problem
     # Finds the parent job and resubmits it with a tighter scf convergence criteria
 
@@ -519,8 +662,22 @@ def resub_tighter(outfile_path):
 
     return True
 
-
 def resub_thermo(outfile_path):
+    """Similar to simple resub, but specific for addressing thermo gradient errors.
+    hecks for the existance of an ultratight version of this run. If it exists, 
+    uses the most up to date version for the new thermo run
+
+    Parameters
+    ----------
+        outfile_path : str
+            The name of an output file.
+    
+    Returns
+    -------
+        Resub_flag : bool
+            True if resubmitted.
+   
+    """
     # Similar to simple resub, but specific for addressing thermo gradient errors
     # Checks for the existance of an ultratight version of this run. If it exists, uses the most up to date version for the new thermo run
 
@@ -553,7 +710,7 @@ def resub_thermo(outfile_path):
             shutil.copy(os.path.join(ultratight_dir, 'scr', 'c0'), os.path.join(directory, 'c0'))
         elif infile_dict['spinmult'] != 1 and os.path.exists(
                 os.path.join(ultratight_dir, 'scr', 'ca0')) and os.path.exists(
-            os.path.join(ultratight_dir, 'scr', 'cb0')):
+                os.path.join(ultratight_dir, 'scr', 'cb0')):
             shutil.copy(os.path.join(ultratight_dir, 'scr', 'ca0'), os.path.join(directory, 'ca0'))
             shutil.copy(os.path.join(ultratight_dir, 'scr', 'cb0'), os.path.join(directory, 'cb0'))
         else:
